#!/usr/bin/python3
"""
"""
from typing import Dict, TypedDict

from ..helps import logger


class GenderedLabel(TypedDict):
    """Represent an Arabic label split into masculine and feminine forms."""

    males: str
    females: str


def normalize_text(text: str) -> str:
    text = text.lower().replace("category:", "")
    # text = text.replace("sportspeople", "sports-people")
    text = text.replace(" the ", " ")
    # text = text.replace("republic of", "republic-of")
    if text.startswith("the "):
        text = text[4:]
    return text.strip()


def combine_value_and_label(
    value: str,
    new_label: str,
    format_key: str = "",
) -> str:
    """
    Combine value and new_label based on format_key.
    Examples:
    - If format_key is "", return "value new_label".
    - If format_key is "{}", return value formatted with new_label.
    - If format_key == "ar", return value formatted with new_label using format_map.
    """
    if not format_key:
        return f"{value} {new_label}"

    if format_key == "{}":
        return value.format(new_label)

    result = value.format_map({format_key: new_label})
    return result


def resolve_suffix_with_mapping_genders(
    category: str,
    data: Dict[str, GenderedLabel],
    callback: callable,
    fix_result_callable: callable = None,
    format_key: str = "",
) -> str:
    """Resolves a category label by finding a matching suffix with gender-specific translations.

    This function iterates through a mapping of suffixes to gendered labels. If a category
    ends with a known suffix, it determines the correct gendered form (male or female)
    based on the presence of 'womens' in the category string. It then recursively calls
    a callback function on the remainder of the category string and combines the results.

    Args:
        category: The input category string to translate.
        data: A dictionary mapping English suffixes to `GenderedLabel` objects.
        callback: A callable that will be used to translate the base category string
            after a suffix is stripped.
        fix_result_callable: An optional callable to apply final fixes to the result.
        format_key: A format string for combining the gendered value and the new label.

    Returns:
        The translated category label, or the result of the callback on the original
        category if no suffix matches.
    """
    logger.debug(f"<<yellow>> start resolve_suffix_with_mapping_genders: {category=}")

    result = ""

    # category = normalize_text(category)
    for key, value in data.items():
        gender_value = value["females"] if "womens" in category else value["males"]
        if category.endswith(key):
            new_category = category[: -len(key)].strip()
            new_label = callback(new_category)
            if new_label:
                result = combine_value_and_label(gender_value, new_label, format_key)
                if fix_result_callable:
                    result = fix_result_callable(result, category, key, gender_value)
            break

    if not result:
        result = callback(category)

    logger.info_if_or_debug(f"<<yellow>> end resolve_suffix_with_mapping_genders: {category=}, {result=}", result)
    return result


def resolve_sport_category_suffix_with_mapping(
    category: str,
    data: dict[str, str],
    callback: callable,
    fix_result_callable: callable = None,
    format_key: str = "",
) -> str:
    """."""
    logger.debug(f"<<yellow>> start resolve_sport_category_suffix_with_mapping: {category=}")

    result = ""

    # category = normalize_text(category)
    for key, value in data.items():
        if category.endswith(key):
            new_category = category[: -len(key)].strip()
            new_label = callback(new_category)
            if new_label:
                result = combine_value_and_label(value, new_label, format_key)
                if fix_result_callable:
                    result = fix_result_callable(result, category, key, value)
            break

    if not result:
        result = callback(category)

    logger.info_if_or_debug(
        f"<<yellow>> end resolve_sport_category_suffix_with_mapping: {category=}, {result=}", result
    )
    return result


__all__ = [
    "resolve_sport_category_suffix_with_mapping",
]



"""
Labs Years processing module.
"""

import functools

from ..helps import logger
from .labs_years import LabsYears

YEAR_PARAM = "{year1}"


@functools.lru_cache(maxsize=1)
def build_labs_years_object() -> LabsYears:
    labs_years_bot = LabsYears()
    return labs_years_bot


def resolve_lab_from_years_patterns(category: str) -> str:
    """Resolve the label from year using LabsYears."""
    logger.debug(f"<<yellow>> start resolve_lab_from_years_patterns: {category=}")

    labs_years_bot = build_labs_years_object()
    _, from_year = labs_years_bot.lab_from_year(category)

    logger.info_if_or_debug(f"<<yellow>> end resolve_lab_from_years_patterns: {category=}, {from_year=}", from_year)
    return from_year



# test_fax2_get_list_of_and_cat3.py
import pytest

from ArWikiCats.new.end_start_bots import fax2

# ---------------------------------------------------------------------------
# 1) Patterns handled by to_get_startswith عبر get_from_starts_dict
# ---------------------------------------------------------------------------


@pytest.mark.fast
def test_get_list_of_and_cat3_all_startswith_patterns() -> None:
    """Each key in to_get_startswith should be matched and produce expected label."""
    for key, tab in fax2.to_get_startswith.items():
        # Build a synthetic category that starts with the key
        suffix = "TestTarget"
        category3 = f"{key}{suffix}"
        category3_nolower = category3

        list_of_cat, foot_ballers, rest = fax2.get_list_of_and_cat3(category3, category3_nolower)

        assert list_of_cat == tab["lab"]
        assert foot_ballers is False
        assert rest == suffix  # Remainder after removing prefix


# ---------------------------------------------------------------------------
# 2) women members of ... (fallback بعد startswith)
# ---------------------------------------------------------------------------


@pytest.mark.fast
def test_get_list_of_and_cat3_women_members_fallback() -> None:
    """The 'women members of ' fallback should be applied when no startswith pattern matches."""
    category3 = "women members of Parliament of the United Kingdom"
    category3_nolower = category3

    list_of_cat, foot_ballers, rest = fax2.get_list_of_and_cat3(category3, category3_nolower)

    assert list_of_cat == "عضوات {}"
    assert foot_ballers is False
    assert rest == "Parliament of the United Kingdom"


# ---------------------------------------------------------------------------
# 3) footballers branches + footballers_get_endswith
# ---------------------------------------------------------------------------


@pytest.mark.parametrize(
    "category3, expected_label, expected_rest",
    [
        (
            "Spanish women's footballers",
            "لاعبات {}",
            "Spanish",
        ),
        (
            "Brazilian female footballers",
            "لاعبات {}",
            "Brazilian",
        ),
        (
            "Heartland F.C. footballers",
            "لاعبو {}",
            "Heartland F.C.",
        ),
        (
            "German footballers",
            "لاعبو {}",
            "German",
        ),
    ],
)
@pytest.mark.fast
def test_get_list_of_and_cat3_footballers_variants(category3: str, expected_label: str, expected_rest: str) -> None:
    """All footballers variants should be handled via footballers_get_endswith."""
    category3_nolower = category3

    list_of_cat, foot_ballers, rest = fax2.get_list_of_and_cat3(category3, category3_nolower)

    assert list_of_cat == expected_label
    assert foot_ballers is True
    assert rest == expected_rest


# ---------------------------------------------------------------------------
# 4) players / playerss branches
# ---------------------------------------------------------------------------


@pytest.mark.parametrize(
    "category3, category3_nolower, expected_rest",
    [
        # Simple players
        (
            "Spanish handball players",
            "Spanish handball players",
            "Spanish handball",
        ),
        # Simple playerss
        (
            "Spanish handball playerss",
            "Spanish handball playerss",
            "Spanish handball",
        ),
        # c. players
        (
            "Heartland F.C. players",
            "Heartland F.C. players",
            "Heartland F.C.",
        ),
        # c. playerss
        (
            "Heartland F.C. playerss",
            "Heartland F.C. playerss",
            "Heartland F.C.",
        ),
        # category3_nolower empty: should fall back to category3
        (
            "Italian basketball players",
            "",
            "Italian basketball",
        ),
    ],
)
@pytest.mark.fast
def test_get_list_of_and_cat3_players_variants(category3: str, category3_nolower: str, expected_rest: str) -> None:
    """All 'players' / 'playerss' endings should set label and strip suffix correctly."""
    list_of_cat, foot_ballers, rest = fax2.get_list_of_and_cat3(category3, category3_nolower)

    assert list_of_cat == "لاعبو {}"
    assert foot_ballers is False
    assert rest == expected_rest


# ---------------------------------------------------------------------------
# 5) stubs branch (app_settings.find_stubs)
# ---------------------------------------------------------------------------


@pytest.mark.fast
def test_get_list_of_and_cat3_stubs_respected_when_enabled() -> None:
    category3 = "Physics stubs"
    category3_nolower = category3

    list_of_cat, foot_ballers, rest = fax2.get_list_of_and_cat3(category3, category3_nolower, True)

    assert list_of_cat == "بذرة {}"
    assert foot_ballers is False
    assert rest == "Physics"


@pytest.mark.fast
def test_get_list_of_and_cat3_stubs_ignored_when_disabled() -> None:
    category3 = "Physics stubs"
    category3_nolower = category3

    list_of_cat, foot_ballers, rest = fax2.get_list_of_and_cat3(category3, category3_nolower, False)

    # No mapping in to_get_endswith, so no label
    assert list_of_cat == ""
    assert foot_ballers is False
    # Only whitespace stripping should be applied
    assert rest == "Physics stubs"


# ---------------------------------------------------------------------------
# 6) Patterns handled by to_get_endswith عبر get_from_endswith_dict
# ---------------------------------------------------------------------------


@pytest.mark.fast
def test_get_list_of_and_cat3_all_endswith_patterns() -> None:
    """Each key in to_get_endswith should be matched and produce expected label."""
    for key, tab in fax2.to_get_endswith.items():
        if tab.get("example"):
            example = tab["example"]
            # Remove 'Category:' prefix if present to mimic typical category3 usage
            if ":" in example:
                category_body = example.split(":", 1)[1]
            else:
                category_body = example
            category3 = category_body
        else:
            # Generic synthetic category
            category3 = f"Foo {key}"

        category3_nolower = category3

        list_of_cat, foot_ballers, rest = fax2.get_list_of_and_cat3(category3, category3_nolower)

        assert list_of_cat == tab["lab"]
        assert foot_ballers is False

        # Check the stripped remainder where we control the format
        if not tab.get("example"):
            assert rest.strip() == "Foo"
        else:
            # For examples we at least ensure remainder + key reconstructs body
            # and is non-empty.
            assert category3.endswith(key)
            expected_rest = category3[: -len(key)]
            assert rest.strip() == expected_rest.strip()


@pytest.mark.fast
def test_get_list_of_and_cat3_navigational_boxes_specificity() -> None:
    """More specific 'squad/sports navigational boxes' should win over plain 'navigational boxes'."""
    # sports navigational boxes
    category3 = "Yemen sports navigational boxes"
    list_of_cat, foot_ballers, rest = fax2.get_list_of_and_cat3(category3, category3)
    assert list_of_cat == fax2.to_get_endswith["sports navigational boxes"]["lab"]
    assert rest.strip() == "Yemen"

    # squad navigational boxes
    category3 = "1996 Basketball Olympic squad navigational boxes"
    list_of_cat, foot_ballers, rest = fax2.get_list_of_and_cat3(category3, category3)
    assert list_of_cat == fax2.to_get_endswith["squad navigational boxes"]["lab"]
    assert rest.strip() == "1996 Basketball Olympic"


# ---------------------------------------------------------------------------
# 7) لا يوجد أي تطابق مع أي نمط
# ---------------------------------------------------------------------------


@pytest.mark.fast
def test_get_list_of_and_cat3_no_match_returns_defaults() -> None:
    """If no startswith/footballers/stubs/players/endswith patterns match, @pytest.mark.fast
    defaults should be returned."""
    category3 = "Completely unmatched category"
    category3_nolower = category3

    list_of_cat, foot_ballers, rest = fax2.get_list_of_and_cat3(category3, category3_nolower)

    assert list_of_cat == ""
    assert foot_ballers is False
    # Leading/trailing whitespace is stripped only
    assert rest == "Completely unmatched category"


# ---------------------------------------------------------------------------
# 8) التأكد من إزالة الفراغات والتعامل مع category3_nolower الفارغ
# ---------------------------------------------------------------------------


@pytest.mark.fast
def test_get_list_of_and_cat3_strips_whitespace_and_handles_empty_nolower() -> None:
    """Whitespace should be stripped and empty category3_nolower handled gracefully."""
    category3 = "  Spanish players  "
    category3_nolower = ""

    list_of_cat, foot_ballers, rest = fax2.get_list_of_and_cat3(category3, category3_nolower)

    assert list_of_cat == "لاعبو {}"
    assert foot_ballers is False
    # Whitespace stripped from both ends
    assert rest == "Spanish"



#
import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats.new_resolvers.relations_resolver import new_relations_resolvers

data_0 = {
    "africanamerican–asian-american relations": "العلاقات الأمريكية الآسيوية الأمريكية الإفريقية",
    "africanamerican–jewish relations": "العلاقات الأمريكية الإفريقية اليهودية",
    "african–native american relations": "العلاقات الأمريكية الأصلية الإفريقية",
    "arab–american relations": "العلاقات الأمريكية العربية",
    "canada–oceanian relations": "العلاقات الأوقيانوسية الكندية",
    "democratic-republic-of-congo–republic-of ireland relations": "العلاقات الأيرلندية الكونغوية الديمقراطية",
    "german–romania military relations": "العلاقات الألمانية الرومانية العسكرية",
    "native american–jewish relations": "العلاقات الأمريكية الأصلية اليهودية",
    "republic-of ireland–united kingdom border crossings": "معابر الحدود الأيرلندية البريطانية",
    "republic-of ireland–united kingdom border": "الحدود الأيرلندية البريطانية",
    "roman–iranian relations": "العلاقات الإيرانية الرومانية",
    "united kingdom–asian relations": "العلاقات الآسيوية البريطانية",
    "united kingdom–middle eastern relations": "العلاقات البريطانية الشرقية الأوسطية",
    "united kingdom–oceanian relations": "العلاقات الأوقيانوسية البريطانية",
    "united states–asian relations": "العلاقات الآسيوية الأمريكية",
    "united states–central american relations": "العلاقات الأمريكية الأمريكية الأوسطية",
    "united states–european relations": "العلاقات الأمريكية الأوروبية",
    "united states–middle eastern relations": "العلاقات الأمريكية الشرقية الأوسطية",
    "united states–north american relations": "العلاقات الأمريكية الأمريكية الشمالية",
    "united states–oceanian relations": "العلاقات الأمريكية الأوقيانوسية",
    "united states–south american relations": "العلاقات الأمريكية الأمريكية الجنوبية",
}

data_3 = {}


@pytest.mark.parametrize("category, expected", data_0.items(), ids=data_0.keys())
@pytest.mark.skip2
def test_data_0(category: str, expected: str) -> None:
    label = new_relations_resolvers(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data_3.items(), ids=data_3.keys())
@pytest.mark.skip2
def test_data_3(category: str, expected: str) -> None:
    label = new_relations_resolvers(category)
    assert label == expected


to_test = [
    ("test_relations_0", data_0),
    # ("test_relations_3", data_3),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.skip2
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, new_relations_resolvers)
    dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""

"""

import pytest

from ArWikiCats.legacy_bots.ma_bots2.country2_label_bot import (
    split_text_by_separator,
)


@pytest.mark.fast
def test_split_text_by_separator_unit() -> None:
    # Test with basic inputs
    result = split_text_by_separator("in", "test in country")
    assert isinstance(result, tuple)
    assert len(result) == 2
    assert isinstance(result[0], str)
    assert isinstance(result[1], str)

    # Test with different separator
    result_various = split_text_by_separator("from", "test from country")
    assert isinstance(result_various, tuple)
    assert len(result_various) == 2
    assert isinstance(result_various[0], str)
    assert isinstance(result_various[1], str)

    # Test with another valid separator
    result_other = split_text_by_separator("to", "test to country")
    assert isinstance(result_other, tuple)
    assert len(result_other) == 2
    assert isinstance(result_other[0], str)
    assert isinstance(result_other[1], str)


class TestSplitTextBySeparatorBasic:
    @pytest.mark.parametrize(
        "separator,country,expected",
        [
            # based in
            (" based in ", "Companies based in Yemen", ("companies", "yemen")),
            # in
            (" in ", "Works in France", ("works", "france")),
            # about
            (" about ", "Books about Yemen", ("books", "yemen")),
            # to
            (" to ", "Flights to Yemen", ("flights", "yemen")),
            # from
            (" from ", "Immigrants from Yemen", ("immigrants", "yemen")),
            # at
            (" at ", "Conference at Sana'a", ("conference", "sana'a")),
            # on
            (" on ", "Report on Yemen", ("report", "yemen")),
        ],
    )
    def test_single_separator_standard_cases(self, separator, country, expected):
        """
        Basic sanity checks for a single occurrence of each standard separator.
        """
        part_1, part_2 = split_text_by_separator(separator, country)
        assert (part_1, part_2) == expected


class TestSplitTextBySeparatorByKeyword:
    @pytest.mark.parametrize(
        "separator,country,expected",
        [
            # Single "by"
            (" by ", "Books by Yemeni authors", ("books", "by yemeni authors")),
            # Capitalization in original text
            (" by ", "BOOKS by Yemeni Authors", ("books", "by yemeni authors")),
        ],
    )
    def test_by_special_handling_single(self, separator, country, expected):
        """
        The 'by' separator must keep 'by' inside the second part.
        """
        part_1, part_2 = split_text_by_separator(separator, country)
        assert (part_1, part_2) == expected

    @pytest.mark.parametrize(
        "separator,country,expected",
        [
            # Repeated "by" – should move to using Type_t / country_t (original case)
            (
                " by ",
                "Books by Yemeni authors by local publishers",
                ("Books", "by Yemeni authors by local publishers"),
            ),
            # Trailing "by" (still should keep everything after first 'by' together)
            (
                " by ",
                "Books by Yemeni authors by",
                ("books", "by yemeni authors by"),
            ),
        ],
    )
    def test_by_special_handling_repeated(self, separator, country, expected):
        """
        When 'by' appears multiple times, the function must collapse everything
        from the first 'by' into the second part while preserving original case
        when test_N is non-trivial.
        """
        part_1, part_2 = split_text_by_separator(separator, country)
        assert (part_1, part_2) == expected


class TestSplitTextBySeparatorRepeatedSeparators:
    @pytest.mark.parametrize(
        "separator,country,expected",
        [
            # based in repeated
            (
                " based in ",
                "Companies based in Yemen based in Sana'a",
                ("Companies", "Yemen based in Sana'a"),
            ),
            # in repeated
            (
                " in ",
                "Works in France in 2015",
                ("Works", "France in 2015"),
            ),
            # about repeated
            (
                " about ",
                "Books about Yemen and about its history",
                ("Books", "Yemen and about its history"),
            ),
            # to repeated
            (
                " to ",
                "Flights to Yemen to Sana'a",
                ("Flights", "Yemen to Sana'a"),
            ),
            # from repeated
            (
                " from ",
                "Immigrants from Yemen from Taiz",
                ("Immigrants", "Yemen from Taiz"),
            ),
            # at repeated
            (
                " at ",
                "Conference at Sana'a at University",
                ("Conference", "Sana'a at University"),
            ),
            # on repeated
            (
                " on ",
                "Report on Yemen on TV",
                ("Report", "Yemen on TV"),
            ),
        ],
    )
    def test_repeated_separator_complex_cases(self, separator, country, expected):
        """
        When the separator appears more than once, split_text_by_separator
        should return:
        - First logical part before the first separator (with original casing)
        - Everything after the first separator (including any extra separators)
        """
        part_1, part_2 = split_text_by_separator(separator, country)
        assert (part_1, part_2) == expected


class TestSplitTextBySeparatorEdgeCases:
    def test_case_insensitive_matching(self):
        """
        Ensure the function behaves correctly when the original string
        has mixed / upper-case characters, while the separator is lower-case.
        """
        separator = " in "
        country = "Works IN France"
        part_1, part_2 = split_text_by_separator(separator, country)
        # Function normalizes to lowercase for the split, so the result is lowercased
        assert (part_1, part_2) == ("works", "france")

    @pytest.mark.parametrize(
        "separator,country,expected",
        [
            # Separator near the end
            (" in ", "Works in France in", ("works", "france in")),
            # Separator at the start (non-typical but good to guard)
            (" in ", "in France in Germany", ("in france", "germany")),
            # Double separators back-to-back
            (" in ", "Works in in France", ("works", "in france")),
        ],
    )
    def test_weird_positioning_of_separator(self, separator, country, expected):
        """
        Stress tests around strange placements of the separator. These ensure that
        the combination of split() + regex + test_N logic remains stable.
        """
        part_1, part_2 = split_text_by_separator(separator, country)
        assert (part_1, part_2) == expected



"""
Unit tests for separator_lists_fixing and add_in_tab functions.

These tests verify the refactored functions work correctly with various inputs
and edge cases.
"""

import pytest

from ArWikiCats.legacy_bots.ma_bots2.ar_lab_bot import (
    _handle_at_separator,
    _handle_in_separator,
    _should_add_min_for_from_separator,
    _should_add_min_for_of_suffix,
    _should_add_preposition_fe,
    add_in_tab,
    separator_lists_fixing,
)


class TestSeparatorListsFixing:
    """Tests for separator_lists_fixing function."""

    def test_add_in_with_in_separator(self) -> None:
        """Test adding 'في' when separator is 'in'."""
        result = separator_lists_fixing("منشآت عسكرية", "in", "military installations in")
        assert result == "منشآت عسكرية في"

    def test_skip_in_when_already_present(self) -> None:
        """Test that 'في' is not added if already present."""
        result = separator_lists_fixing("منشآت عسكرية في", "in", "military installations in")
        assert result == "منشآت عسكرية في"

    def test_add_in_with_at_separator(self) -> None:
        """Test adding 'في' when separator is 'at'."""
        result = separator_lists_fixing("رياضة", "at", "sport at")
        assert result == "رياضة في"

    def test_skip_in_with_at_when_already_present(self) -> None:
        """Test that 'في' is not added with 'at' if already present."""
        result = separator_lists_fixing("رياضة في", "at", "sport at")
        assert result == "رياضة في"

    def test_no_change_for_non_listed_separator(self) -> None:
        """Test that label is unchanged for separators not in separators_lists_raw."""
        result = separator_lists_fixing("منشآت عسكرية", "about", "military installations")
        assert result == "منشآت عسكرية"

    def test_from_separator_returns_unchanged(self) -> None:
        """Test that 'from' separator doesn't add 'في'."""
        result = separator_lists_fixing("رياضيون", "from", "athletes")
        assert result == "رياضيون"

    def test_by_separator_returns_unchanged(self) -> None:
        """Test that 'by' separator doesn't add 'في'."""
        result = separator_lists_fixing("لوحات", "by", "paintings")
        assert result == "لوحات"

    def test_of_separator_returns_unchanged(self) -> None:
        """Test that 'of' separator doesn't add 'في'."""
        result = separator_lists_fixing("تاريخ", "of", "history")
        assert result == "تاريخ"

    def test_skip_in_for_exception_types(self, monkeypatch: pytest.MonkeyPatch) -> None:
        """Test that 'في' is not added for types in pop_of_without_in."""
        monkeypatch.setattr(
            "ArWikiCats.ma_bots2.ar_lab_bot.pop_of_without_in",
            ["populations"],
            raising=False,
        )

        result = separator_lists_fixing("سكان", "in", "populations")
        assert result == "سكان"


class TestAddInTab:
    """Tests for add_in_tab function."""

    def test_add_من_with_from_separator(self) -> None:
        """Test adding 'من' when separator is 'from'."""
        result = add_in_tab("رياضيون", "athletes", "from")
        assert result == "رياضيون من "

    def test_skip_من_when_already_present(self) -> None:
        """Test that 'من' is not added if already present."""
        result = add_in_tab("رياضيون من", "athletes", "from")
        assert result == "رياضيون من"

    def test_add_من_for_of_suffix(self, monkeypatch: pytest.MonkeyPatch) -> None:
        """Test adding 'من' when type ends with ' of' and is in tables."""
        monkeypatch.setattr(
            "ArWikiCats.ma_bots2.ar_lab_bot.get_pop_All_18",
            lambda *_: "some_value",
            raising=False,
        )
        monkeypatch.setattr(
            "ArWikiCats.ma_bots2.ar_lab_bot.check_key_new_players",
            lambda *_: True,
            raising=False,
        )

        result = add_in_tab("رياضيون", "athletes of", "in")
        assert result == "رياضيون من "

    def test_skip_من_when_no_ty_in18(self, monkeypatch: pytest.MonkeyPatch) -> None:
        """Test that 'من' is not added when get_pop_All_18 returns None."""
        monkeypatch.setattr(
            "ArWikiCats.ma_bots2.ar_lab_bot.get_pop_All_18",
            lambda *_: None,
            raising=False,
        )

        result = add_in_tab("رياضيون", "athletes of", "in")
        assert result == "رياضيون"

    def test_skip_من_when_not_ending_with_of(self, monkeypatch: pytest.MonkeyPatch) -> None:
        """Test that 'من' is not added when type doesn't end with ' of'."""
        monkeypatch.setattr(
            "ArWikiCats.ma_bots2.ar_lab_bot.get_pop_All_18",
            lambda *_: "some_value",
            raising=False,
        )

        result = add_in_tab("رياضيون", "athletes", "in")
        assert result == "رياضيون"

    def test_skip_من_when_in_in_label(self, monkeypatch: pytest.MonkeyPatch) -> None:
        """Test that 'من' is not added when 'في' is already in label."""
        monkeypatch.setattr(
            "ArWikiCats.ma_bots2.ar_lab_bot.get_pop_All_18",
            lambda *_: "some_value",
            raising=False,
        )

        result = add_in_tab("رياضيون في", "athletes of", "in")
        assert result == "رياضيون في"

    def test_skip_من_when_not_in_tables(self, monkeypatch: pytest.MonkeyPatch) -> None:
        """Test that 'من' is not added when type is not in tables."""
        monkeypatch.setattr(
            "ArWikiCats.ma_bots2.ar_lab_bot.get_pop_All_18",
            lambda *_: "some_value",
            raising=False,
        )
        monkeypatch.setattr(
            "ArWikiCats.ma_bots2.ar_lab_bot.check_key_new_players",
            lambda *_: False,
            raising=False,
        )

        result = add_in_tab("رياضيون", "athletes of", "in")
        assert result == "رياضيون"

    def test_add_من_when_prefix_in_tables(self, monkeypatch: pytest.MonkeyPatch) -> None:
        """Test adding 'من' when type prefix (without ' of') is in tables."""
        monkeypatch.setattr(
            "ArWikiCats.ma_bots2.ar_lab_bot.get_pop_All_18",
            lambda *_: "some_value",
            raising=False,
        )

        calls = iter([False, True])

        def fake_check_key(*_):
            return next(calls)

        monkeypatch.setattr(
            "ArWikiCats.ma_bots2.ar_lab_bot.check_key_new_players",
            fake_check_key,
            raising=False,
        )

        result = add_in_tab("رياضيون", "athletes of", "in")
        assert result == "رياضيون من "

    def test_with_trailing_space_in_label(self) -> None:
        """Test handling of labels with trailing spaces."""
        result = add_in_tab("رياضيون   ", "athletes", "from")
        assert result == "رياضيون    من "


class TestHelperFunctions:
    """Tests for helper functions."""

    def test_should_add_preposition_in_true(self) -> None:
        """Test _should_add_preposition_fe returns True when conditions are met."""
        assert _should_add_preposition_fe("منشآت عسكرية", "military installations in") is True

    def test_should_add_preposition_in_false_when_in_present(self) -> None:
        """Test _should_add_preposition_fe returns False when 'في' is present."""
        assert _should_add_preposition_fe("منشآت عسكرية في", "military installations in") is False

    def test_should_add_preposition_in_false_when_no_in(self) -> None:
        """Test _should_add_preposition_fe returns False when ' in' (with space) is not in type_lower.

        'installations' contains substring 'in' but not ' in' with a leading space.
        """
        result = _should_add_preposition_fe("منشآت عسكرية", "military installations")
        # " in" (with space) is not in "military installations", so should be False
        assert result is True

    def test_handle_in_separator_adds_في(self, monkeypatch: pytest.MonkeyPatch) -> None:
        """Test _handle_in_separator adds 'في' when conditions are met."""
        monkeypatch.setattr(
            "ArWikiCats.ma_bots2.ar_lab_bot.pop_of_without_in",
            [],
            raising=False,
        )

        result = _handle_in_separator("منشآت عسكرية", "in", "military installations in")
        assert result == "منشآت عسكرية في"

    def test_handle_in_separator_skips_for_exceptions(self, monkeypatch: pytest.MonkeyPatch) -> None:
        """Test _handle_in_separator skips adding 'في' for exception types."""
        monkeypatch.setattr(
            "ArWikiCats.ma_bots2.ar_lab_bot.pop_of_without_in",
            ["military installations in"],
            raising=False,
        )

        result = _handle_in_separator("منشآت عسكرية", "in", "military installations in")
        assert result == "منشآت عسكرية"

    def test_handle_at_separator_adds_في(self) -> None:
        """Test _handle_at_separator adds 'في' when conditions are met."""
        result = _handle_at_separator("رياضة", "sport at")
        assert result == "رياضة في"

    def test_handle_at_separator_skips_when_in_present(self) -> None:
        """Test _handle_at_separator doesn't add 'في' when already present."""
        result = _handle_at_separator("رياضة في", "sport at")
        assert result == "رياضة في"

    def test_should_add_min_for_from_separator_true(self) -> None:
        """Test _should_add_min_for_from_separator returns True when 'من' not present."""
        assert _should_add_min_for_from_separator("رياضيون") is True

    def test_should_add_min_for_from_separator_false(self) -> None:
        """Test _should_add_min_for_from_separator returns False when 'من' is present."""
        assert _should_add_min_for_from_separator("رياضيون من") is False

    def test_should_add_min_for_from_separator_with_spaces(self) -> None:
        """Test _should_add_min_for_from_separator handles trailing spaces."""
        assert _should_add_min_for_from_separator("رياضيون   ") is True

    def test_should_add_min_for_of_suffix_true(self) -> None:
        """Test _should_add_min_for_of_suffix returns True when all conditions are met."""
        assert _should_add_min_for_of_suffix("athletes of", "some_value", "رياضيون") is True

    def test_should_add_min_for_of_suffix_false_no_ty_in18(self) -> None:
        """Test _should_add_min_for_of_suffix returns False when ty_in18 is None."""
        assert _should_add_min_for_of_suffix("athletes of", None, "رياضيون") is False

    def test_should_add_min_for_of_suffix_false_no_of(self) -> None:
        """Test _should_add_min_for_of_suffix returns False when type doesn't end with ' of'."""
        assert _should_add_min_for_of_suffix("athletes", "some_value", "رياضيون") is False

    def test_should_add_min_for_of_suffix_false_in_present(self) -> None:
        """Test _should_add_min_for_of_suffix returns False when 'في' is in label."""
        assert _should_add_min_for_of_suffix("athletes of", "some_value", "رياضيون في") is False


class TestEdgeCases:
    """Tests for edge cases and special scenarios."""

    def test_separator_lists_fixing_empty_strings(self) -> None:
        """Test separator_lists_fixing with empty strings."""
        result = separator_lists_fixing("", "", "")
        assert result == ""

    def test_add_in_tab_empty_strings(self) -> None:
        """Test add_in_tab with empty strings."""
        result = add_in_tab("", "", "")
        assert result == ""

    def test_separator_lists_fixing_with_special_characters(self) -> None:
        """Test separator_lists_fixing with Arabic text containing special characters."""
        result = separator_lists_fixing("منشآت-عسكرية", "in", "military installations in")
        assert "في" in result

    def test_add_in_tab_with_multiple_spaces(self) -> None:
        """Test add_in_tab with multiple spaces in label."""
        result = add_in_tab("رياضيون    ", "athletes", "from")
        assert "من" in result

    def test_separator_lists_fixing_case_sensitivity(self) -> None:
        """Test that function works correctly with lowercase type_lower."""
        result = separator_lists_fixing("منشآت عسكرية", "in", "MILITARY INSTALLATIONS IN")
        # type_lower should be lowercase so this should not match
        assert result == "منشآت عسكرية"

    def test_add_in_tab_removesuffix_python_39(self, monkeypatch: pytest.MonkeyPatch) -> None:
        """Test that removesuffix method works correctly (Python 3.9+)."""
        monkeypatch.setattr(
            "ArWikiCats.ma_bots2.ar_lab_bot.get_pop_All_18",
            lambda *_: "some_value",
            raising=False,
        )

        # This should work even if removesuffix is used
        result = add_in_tab("رياضيون", "athletes of", "in")

        # Function should handle the ' of' removal correctly
        assert isinstance(result, str)


if __name__ == "__main__":
    pytest.main([__file__, "-v"])



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_label_ar

data0 = {
    "russian empire-united states relations": "العلاقات بين الإمبراطورية الروسية والولايات المتحدة",
    "south korean presidential election 2017": "الانتخابات الرئاسية الكورية الجنوبية 2017",
    "republic of ireland women's national football team": "منتخب جمهورية أيرلندا لكرة القدم للسيدات",
}

data_1 = {
    "ivorian people": "إيفواريون",
    "japanese lgbtq people": "أعلام إل جي بي تي كيو يابانيون",
    "chinese lgbtq people": "أعلام إل جي بي تي كيو صينيون",
    "arab lgbtq people": "أعلام إل جي بي تي كيو عرب",
    "rwandan political people": "ساسة روانديون",
    "maldivian people": "مالديفيون",
    "malian people": "ماليون",
    "maltese lgbtq people": "أعلام إل جي بي تي كيو مالطيون",
    "namibia–russia relations": "العلاقات الروسية الناميبية",
    "morocco–netherlands relations": "العلاقات المغربية الهولندية",
    "morocco–pakistan relations": "العلاقات الباكستانية المغربية",
    "morocco–qatar relations": "العلاقات القطرية المغربية",
    "morocco–russia relations": "العلاقات الروسية المغربية",
    "morocco–united kingdom relations": "العلاقات البريطانية المغربية",
    "mongolia–russia relations": "العلاقات الروسية المنغولية",
    "mauritania–morocco relations": "العلاقات المغربية الموريتانية",
    "mauritania–russia relations": "العلاقات الروسية الموريتانية",
    "south korea–united states relations": "العلاقات الأمريكية الكورية الجنوبية",
    "somalia–turkey relations": "العلاقات التركية الصومالية",
    "russia–sudan relations": "العلاقات الروسية السودانية",
    "russia–tunisia relations": "العلاقات التونسية الروسية",
    "russia–united arab emirates relations": "العلاقات الإماراتية الروسية",
    "russia–uzbekistan relations": "العلاقات الأوزبكستانية الروسية",
    "philippine–american war": "الحرب الأمريكية الفلبينية",
    "philippines–saudi arabia relations": "العلاقات السعودية الفلبينية",
    "palestine national basketball team": "منتخب فلسطين لكرة السلة",
    "russia men's national ice hockey team": "منتخب روسيا لهوكي الجليد للرجال",
    "palestine–united arab emirates relations": "العلاقات الإماراتية الفلسطينية",
    "palestine–united kingdom relations": "العلاقات البريطانية الفلسطينية",
    "palestine–uruguay relations": "العلاقات الأوروغويانية الفلسطينية",
    "african championships in athletics": "بطولات إفريقية في ألعاب القوى",
    "automotive industry in italy": "صناعة سيارات في إيطاليا",
    "bahrain in the asian para games": "البحرين في الألعاب البارالمبية الآسيوية",
    "field hockey in the 2004 summer olympics": "هوكي الميدان في الألعاب الأولمبية الصيفية 2004",
    "gymnastics in the 2004 summer olympics": "الجمباز في الألعاب الأولمبية الصيفية 2004",
    "history of the petroleum industry in canada": "تاريخ صناعة بترولية في كندا",
    "internet in bahrain": "إنترنت في البحرين",
    "islam in bermuda": "الإسلام في برمودا",
    "kingdom of hungary in the middle ages": "مملكة المجر في العصور الوسطى",
    "kurds in syria": "الأكراد في سوريا",
    "kurds in turkey": "الأكراد في تركيا",
    "protestantism in morocco": "البروتستانتية في المغرب",
    "protestantism in yemen": "البروتستانتية في اليمن",
    "same-sex marriage in the netherlands": "زواج مثلي في هولندا",
    "shia islam in afghanistan": "الشيعة في أفغانستان",
    "shooting in the 2004 summer olympics": "الرماية في الألعاب الأولمبية الصيفية 2004",
    "silver mining in the united states": "التنقيب عن الفضة في الولايات المتحدة",
    "swimming in the 2004 summer olympics": "السباحة في الألعاب الأولمبية الصيفية 2004",
    "synchronized swimming in the 2004 summer olympics": "السباحة المتزامنة في الألعاب الأولمبية الصيفية 2004",
    "taekwondo in the 2004 summer olympics": "التايكوندو في الألعاب الأولمبية الصيفية 2004",
    "time in azerbaijan": "الزمن في أذربيجان",
    "time in cyprus": "الزمن في قبرص",
    "triathlon in the 2004 summer olympics": "السباق الثلاثي في الألعاب الأولمبية الصيفية 2004",
    "women in niue": "المرأة في نييوي",
    "women in pala": "المرأة في بالاو",
    "women in the cook islands": "المرأة في جزر كوك",
    "women in the federated states of micronesia": "المرأة في ولايات ميكرونيسيا المتحدة",
    "women in the federated states-of micronesia": "المرأة في ولايات ميكرونيسيا المتحدة",
    "wrestling in the 2004 summer olympics": "المصارعة في الألعاب الأولمبية الصيفية 2004",
    "wrestling in the 2016 summer olympics": "المصارعة في الألعاب الأولمبية الصيفية 2016",
    "saudi arabia–ukraine relations": "العلاقات الأوكرانية السعودية",
    "china–sudan relations": "العلاقات السودانية الصينية",
    "china-sudan relations": "العلاقات السودانية الصينية",
    "saudi arabia-ukraine relations": "العلاقات الأوكرانية السعودية",
    "mauritania-morocco relations": "العلاقات المغربية الموريتانية",
    "mauritania-russia relations": "العلاقات الروسية الموريتانية",
    "mongolia-russia relations": "العلاقات الروسية المنغولية",
    "morocco-netherlands relations": "العلاقات المغربية الهولندية",
    "morocco-pakistan relations": "العلاقات الباكستانية المغربية",
    "morocco-qatar relations": "العلاقات القطرية المغربية",
    "morocco-russia relations": "العلاقات الروسية المغربية",
    "morocco-united kingdom relations": "العلاقات البريطانية المغربية",
    "namibia-russia relations": "العلاقات الروسية الناميبية",
    "palestine-united arab emirates relations": "العلاقات الإماراتية الفلسطينية",
    "palestine-united kingdom relations": "العلاقات البريطانية الفلسطينية",
    "palestine-uruguay relations": "العلاقات الأوروغويانية الفلسطينية",
    "philippines-saudi arabia relations": "العلاقات السعودية الفلبينية",
    "russia-sudan relations": "العلاقات الروسية السودانية",
    "russia-tunisia relations": "العلاقات التونسية الروسية",
    "russia-united arab emirates relations": "العلاقات الإماراتية الروسية",
    "russia-uzbekistan relations": "العلاقات الأوزبكستانية الروسية",
    "somalia-turkey relations": "العلاقات التركية الصومالية",
    "south korea-united states relations": "العلاقات الأمريكية الكورية الجنوبية",
    "lists of populated places in the united states": "قوائم أماكن مأهولة في الولايات المتحدة",
    "populated places in the british virgin islands": "أماكن مأهولة في جزر العذراء البريطانية",
    "soccer in australia": "كرة القدم في أستراليا",
    "soccer in the united states": "كرة القدم في الولايات المتحدة",
    "football in spain": "كرة القدم في إسبانيا",
    "water polo in the world aquatics championships": "كرة الماء في بطولة العالم للرياضات المائية",
    "populated places in tokelau": "أماكن مأهولة في توكيلاو",
    "townships in michigan": "ضواحي مدن في ميشيغان",
    "populated places in christmas island": "أماكن مأهولة في جزيرة عيد الميلاد",
    "cities and towns in india": "مدن وبلدات في الهند",
    "neighbourhoods in rio de janeiro (city)": "أحياء في ريو دي جانيرو",
    "populated places in the cocos (keeling) islands": "أماكن مأهولة في جزر كوكوس",
    "populated places in puebla": "أماكن مأهولة في ولاية بويبلا",
    "populated places in the cook islands": "أماكن مأهولة في جزر كوك",
    "populated places in norfolk island": "أماكن مأهولة في جزيرة نورفولك",
    "cities and towns in moscow oblast": "مدن وبلدات في محافظة موسكو",
    "wheelchair basketball world championship": "بطولة العالم لكرة السلة على الكراسي المتحركة",
    "water polo at the world aquatics championships": "كرة الماء في بطولة العالم للرياضات المائية",
    "portugal national rugby league team": "منتخب البرتغال لدوري الرجبي",
    "new zealand women's national ice hockey team": "منتخب نيوزيلندا لهوكي الجليد للسيدات",
    "new zealand women's national rugby league team": "منتخب نيوزيلندا لدوري الرجبي للسيدات",
    "kazakhstan women's national ice hockey team": "منتخب كازاخستان لهوكي الجليد للسيدات",
    "georgia national rugby union team": "منتخب جورجيا لاتحاد الرجبي",
    "england women's national rugby league team": "منتخب إنجلترا لدوري الرجبي للسيدات",
    "chile national rugby union team": "منتخب تشيلي لاتحاد الرجبي",
    "australia national rugby union team": "منتخب أستراليا لاتحاد الرجبي",
    "algeria national rugby union team": "منتخب الجزائر لاتحاد الرجبي",
    "united states national rugby union team": "منتخب الولايات المتحدة لاتحاد الرجبي",
    "greece national rugby league team": "منتخب اليونان لدوري الرجبي",
    "archery at the 2004 summer olympics": "النبالة في الألعاب الأولمبية الصيفية 2004",
    "wrestling at the 2004 summer olympics": "المصارعة في الألعاب الأولمبية الصيفية 2004",
    "triathlon at the 2004 summer olympics": "السباق الثلاثي في الألعاب الأولمبية الصيفية 2004",
    "synchronized swimming at the 2004 summer olympics": "السباحة المتزامنة في الألعاب الأولمبية الصيفية 2004",
    "united states national futsal team": "منتخب الولايات المتحدة لكرة الصالات",
    "thailand women's national basketball team": "منتخب تايلاند لكرة السلة للسيدات",
    "sweden national bandy team": "منتخب السويد للباندي",
    "slovenia women's national football team": "منتخب سلوفينيا لكرة القدم للسيدات",
    "papua new guinea women's national football team": "منتخب بابوا غينيا الجديدة لكرة القدم للسيدات",
    "netherlands men's national basketball team": "منتخب هولندا لكرة السلة للرجال",
    "taekwondo at the 2004 summer olympics": "التايكوندو في الألعاب الأولمبية الصيفية 2004",
    "namibia women's national football team": "منتخب ناميبيا لكرة القدم للسيدات",
    "myanmar women's national football team": "منتخب ميانمار لكرة القدم للسيدات",
    "montenegro women's national football team": "منتخب الجبل الأسود لكرة القدم للسيدات",
    "moldova national rugby league team": "منتخب مولدوفا لدوري الرجبي",
    "moldova women's national football team": "منتخب مولدوفا لكرة القدم للسيدات",
    "philippine football federation": "الاتحاد الفلبيني لكرة القدم",
    "iraq national football team results": "نتائج منتخب العراق لكرة القدم",
    "austria women's national football team": "منتخب النمسا لكرة القدم للسيدات",
    "algeria women's national football team": "منتخب الجزائر لكرة القدم للسيدات",
    "thailand women's national football team": "منتخب تايلاند لكرة القدم للسيدات",
    "switzerland women's national football team": "منتخب سويسرا لكرة القدم للسيدات",
    "portugal women's national football team": "منتخب البرتغال لكرة القدم للسيدات",
    "vietnam national basketball team": "منتخب فيتنام لكرة السلة",
    "uruguay national football team": "منتخب أوروغواي لكرة القدم",
    "bolivia national soccer team": "منتخب بوليفيا لكرة القدم",
}

data_2 = {
    "Austrian Giro d'Italia stage winners": "فائزون في مراحل طواف إيطاليا نمساويون",
    "Azerbaijani men marathon runners": "عداؤو ماراثون أذربيجانيون",
    "Brazilian men sprinters": "عداؤون سريعون برازيليون",
    "Burmese men long-distance runners": "عداؤو مسافات طويلة بورميون",
    "Estonian men long-distance runners": "عداؤو مسافات طويلة إستونيون",
    "Gibraltarian men athletes": "لاعبو قوى جبل طارقيون",
    "Nazis executed by the British military": "نازيون أعدموا من قبل الجيش البريطاني",
    "People executed by the British military": "أشخاص أعدموا من قبل الجيش البريطاني",
    "People executed by the French military": "أشخاص أعدموا من قبل الجيش الفرنسي",
    "women in danish military": "المرأة في الجيش الدنماركي",
    "brazilian women's rights activists": "برازيليون ناشطون في حقوق المرأة",
    "burmese men marathon runners": "عداؤو ماراثون بورميون",
    "canadian men": "رجال كنديون",
    "Men's basketball players from Northern Ireland": "لاعبو كرة سلة من أيرلندا الشمالية",
    "Men's footballers in Papua New Guinea": "لاعبو كرة قدم في بابوا غينيا الجديدة",
    "men's footballers in togo": "لاعبو كرة قدم في توغو",
    "puerto rican men high jumpers": "متسابقو قفز عالي بورتوريكيون",
    "turkish women's rights activists": "أتراك ناشطون في حقوق المرأة",
    "Chilean men shot putters": "لاعبو دفع ثقل تشيليون",
    "Somalian men sprinters": "عداؤون سريعون صوماليون",
    "Sculptures of men in England": "منحوتات في رجال في إنجلترا",
    "Sculptures of men in London": "منحوتات في رجال في لندن",
    "Algerian men middle-distance runners": "عداؤو مسافات متوسطة جزائريون",
    "Guatemalan men middle-distance runners": "عداؤو مسافات متوسطة غواتيماليون",
    "Haitian men athletes": "لاعبو قوى هايتيون",
    "Iranian men athletes": "لاعبو قوى إيرانيون",
    "Iraqi men middle-distance runners": "عداؤو مسافات متوسطة عراقيون",
    "Kyrgyzstani men marathon runners": "عداؤو ماراثون قيرغيزستانيون",
    "Liechtenstein men sprinters": "عداؤون سريعون ليختنشتانيون",
    "Macedonian men sprinters": "عداؤون سريعون مقدونيون",
    "Men discus throwers": "رماة قرص",
    "Men's footballers in Mongolia": "لاعبو كرة قدم في منغوليا",
    "Nicaraguan men high jumpers": "متسابقو قفز عالي نيكاراغويون",
    "Russian men pole vaulters": "قافزون بالزانة روس",
    "Taiwanese men long jumpers": "لاعبو قفز طويل تايوانيون",
    "Trinidad and Tobago men discus throwers": "رماة قرص ترنيداديون",
    "Abolitionists from Wisconsin": "مناهضون للعبودية من ويسكونسن",
    "Albanian women's rights activists": "ألبان ناشطون في حقوق المرأة",
    "Botswana women's rights activists": "بوتسوانيون ناشطون في حقوق المرأة",
    "Venezuelan women's rights activists": "فنزويليون ناشطون في حقوق المرأة",
}

data_3 = {}


@pytest.mark.parametrize("category, expected", data_2.items(), ids=data_2.keys())
@pytest.mark.fast
def test_2(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


to_test = [
    ("test_1", data_1),
    ("test_2", data_2),
    ("test_3", data_3),
]


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""Regional translation helpers for administrative areas."""

from ...helps import len_print
from ..utils.json_dir import open_json_file

COUNTRY_ADMIN_LABELS = open_json_file("geography/P17_PP.json") or {}
ADDITIONAL_REGION_KEYS = open_json_file("geography/New_Keys.json") or {}

SWISS_CANTON_LABELS = {
    "aarga": "أرجاو",
    "aargau": "أرجاو",
    "appenzell ausserrhoden": "أبينزيل أوسيرهودن",
    "appenzell innerrhoden": "أبينزيل إينرهودن",
    "basel-landschaft": "ريف بازل",
    "basel-land": "ريف بازل",
    "basel-stadt": "مدينة بازل",
    "bern": "برن",
    "fribourg": "فريبورغ",
    "geneva": "جنيف",
    "glarus": "غلاروس",
    "graubünden": "غراوبوندن",
    "grisons": "غراوبوندن",
    "jura": "جورا",
    "lucerne": "لوسيرن",
    "neuchâtel": "نيوشاتل",
    "nidwalden": "نيدفالدن",
    "obwalden": "أوبفالدن",
    "schaffhausen": "شافهوزن",
    "schwyz": "شفيتس",
    "solothurn": "سولوتورن",
    "st. gallen": "سانت غالن",
    "thurga": "تورغاو",
    "thurgau": "تورغاو",
    "ticino": "تيسينو",
    "uri": "أوري",
    "valais": "فاليز",
    "vaud": "فود",
    "zug": "تسوغ",
    "zürich": "زيورخ",
}

PROVINCE_LABEL_OVERRIDES = {
    "quintana roo": "ولاية كينتانا رو",
    "tamaulipas": "ولاية تاماوليباس",
    "campeche": "ولاية كامبيتشي",
    "helmand": "ولاية هلمند",
    "nuristan": "ولاية نورستان",
    "badghis": "ولاية بادغيس",
    "badakhshan": "ولاية بدخشان",
    "kapisa": "ولاية كابيسا",
    "baghlan": "ولاية بغلان",
    "daykundi": "ولاية دايكندي",
    "kandahar": "ولاية قندهار",
    "bamyan": "ولاية باميان",
    "nangarhar": "ولاية ننكرهار",
    "aklan": "ولاية أكلان",
    "zacatecas": "ولاية زاكاتيكاس",
    "zabul": "ولاية زابل",
    "balkh": "ولاية بلخ",
    "tlaxcala": "ولاية تلاكسكالا",
    "sinaloa": "ولاية سينالوا",
    "nam định": "محافظة نام دنه",
    "malampa": "محافظة مالامبا",
    "đắk lắk": "محافظة داك لاك",
    "lâm đồng": "محافظة لام دونغ",
    "điện biên": "محافظة دين بين",
    "northern province": "المحافظة الشمالية (زامبيا)",
    "central java province": "جاوة الوسطى",
    "south hwanghae province": "جنوب مقاطعة هوانغاي",
    "north sumatra province": "سومطرة الشمالية",
    "sancti spíritus province": "سانكتي سبيريتوس",
    "formosa province": "فورموسا",
    "orientale province": "أوريونتال",
    "western province": "المحافظة الغربية (زامبيا)",
    "papua province": "بابوا",
    "jambi province": "جمبي",
    "east nusa tenggara province": "نوسا تنقارا الشرقية",
    "southeast sulawesi province": "سولاوسي الجنوبية الشرقية",
    "chagang province": "تشاغانغ",
    "gorontalo province": "غورونتالو",
    "riau province": "رياو",
    "chaco province": "شاكو",
    "jujuy province": "خوخوي",
    "holguín province": "هولغوين",
    "north maluku province": "مالوكو الشمالية",
    "central province": "المحافظة الوسطى (زامبيا)",
    "central sulawesi province": "سولاوسي الوسطى",
    "southern province": "المحافظة الجنوبية (زامبيا)",
    "west papua province": "بابوا الغربية",
    "copperbelt province": "كوبربيلت",
    "granma province": "غرانما",
    "cienfuegos province": "سينفويغوس",
    "santiago de cuba province": "سانتياغو دي كوبا",
    "salavan province": "سالافان",
    "équateur province": "إكواتور",
    "entre ríos province": "إنتري ريوس",
    "north pyongan province": "بيونغان الشمالية",
    "west java province": "جاوة الغربية",
    "eastern province": "المحافظة الشرقية (زامبيا)",
    "north hwanghae province": "هوانغهاي الشمالية",
    "northwestern province": "المحافظة الشمالية الغربية (زامبيا)",
    "córdoba province": "كوردوبا",
    "matanzas": "ماتنزاس",
    "matanzas province": "مقاطعة ماتنزاس",
    "north sulawesi province": "سولاوسي الشمالية",
    "osh region": "أوش أوبلاستي",
    "puno region": "بونو",
    "flemish region": "الإقليم الفلامندي",
    "zanzibar urban/west region": "زنجبار الحضرية / المقاطعة الغربية",
    "talas region": "طلاس أوبلاستي",
    "tansift region": "جهة تانسيفت",
    "central region": "الجهة الوسطى",
    "northwestern region": "الجهة الشمالية الغربية",
    "cajamarca region": "كاخاماركا",
    "sacatepéquez department": "ساكاتيبيكيز",
    "escuintla department": "إسكوينتلا",
    "prevalje municipality": "بريفالجه",
    "moravče municipality": "مورافسكه (مورافسكه)",
    "vraneštica municipality": "فرانيستيكا (كيسيفو)",
    "vasilevo municipality": "فاسيليفو",
    "šentjernej municipality": "شينتيرني",
}

REGION_SUFFIXES_EN = [
    " province",
    " district",
    " state",
    " region",
    " division",
    " county",
    " department",
    " municipality",
    " governorate",
    " voivodeship",
]
REGION_PREFIXES_AR = [
    "ولاية ",
    "الشعبة ",
    "شعبة ",
    "القسم ",
    "قسم ",
    "منطقة ",
    "محافظة ",
    "مقاطعة ",
    "إدارة ",
    "بلدية ",
    "إقليم ",
    "اقليم ",
]

PROVINCE_LABELS = {
    "antananarivo": "فيانارانتسوا",
    "antsiranana": "أنتسيرانانا",
    "artemisa": "أرتيميسا",
    "bandundu": "بانداندو",
    "banten": "بنتن",
    "bas-congo": "الكونغو الوسطى",
    "bengkulu": "بنغكولو",
    "bengo": "بنغو",
    "benguela": "بنغيلا",
    "bié": "بيي",
    "buenos aires": "بوينس آيرس",
    "cabinda": "كابيندا",
    "camagüey": "كاماغوي",
    "cuando cubango": "كواندو كوبانغو",
    "cuanza norte": "كوانزا نورت",
    "cunene": "كونيني",
    "fianarantsoa": "فيانارانتسوا",
    "guantánamo": "غوانتانامو",
    "huambo": "هوامبو",
    "kangwon": "كانغوون",
    "katanga": "كاتانغا",
    "lampung": "لامبونغ",
    "las tunas": "لاس توناس",
    "luanda": "لواندا",
    "lunda norte": "لوندا نورتي",
    "lunda sul": "لوندا سول",
    "lusaka": "لوساكا",
    "mahajanga": "ماهاجانجا",
    "malanje": "مالانجي",
    "maluku": "مالوكو",
    "moxico": "موكسيكو",
    "namibe": "ناميبي",
    "ogooué-lolo": "أوغووي-لولو",
    "ogooué-maritime": "أوغووي - البحرية",
    "ryanggang": "ريانغانغ",
    "south pyongan": "بيونغان الجنوبية",
    "toamasina": "تواماسينا",
    "toliara": "توليارا",
    "uíge": "أوجي",
    "woleu-ntem": "وليو-نتم",
    "zaire": "زائير",
}

COUNTRY_ADMIN_LABELS.update({k.lower(): v for k, v in SWISS_CANTON_LABELS.items()})

for canton, value in SWISS_CANTON_LABELS.items():
    COUNTRY_ADMIN_LABELS[f"canton-of {canton.lower()}"] = f"كانتون {value}"

COUNTRY_ADMIN_LABELS.update({k.lower(): v for k, v in ADDITIONAL_REGION_KEYS.items()})

COUNTRY_ADMIN_LABELS.update({k.lower(): v for k, v in PROVINCE_LABEL_OVERRIDES.items()})

region_suffix_matches = {}

for cc, lab in ADDITIONAL_REGION_KEYS.items():
    should_update = True
    cc2 = cc.lower()
    for en_k in REGION_SUFFIXES_EN:
        for ar_k in REGION_PREFIXES_AR:
            if should_update and cc2.endswith(en_k) and lab.startswith(ar_k):
                should_update = False
                cc3 = cc2[: -len(en_k)]
                lab_2 = lab[len(ar_k) :]
                region_suffix_matches[cc3] = lab_2

COUNTRY_ADMIN_LABELS.update(region_suffix_matches)

for city, city_lab in PROVINCE_LABELS.items():
    city2 = city.lower()
    if city_lab:
        COUNTRY_ADMIN_LABELS[city2] = city_lab
        COUNTRY_ADMIN_LABELS[f"{city2} province"] = f"مقاطعة {city_lab}"
        COUNTRY_ADMIN_LABELS[f"{city2} (province)"] = f"مقاطعة {city_lab}"


__all__ = [
    "COUNTRY_ADMIN_LABELS",
]

len_print.data_len(
    "labels_country2.py",
    {
        "COUNTRY_ADMIN_LABELS": COUNTRY_ADMIN_LABELS,  # 1,778
        "ADDITIONAL_REGION_KEYS": ADDITIONAL_REGION_KEYS,
        "SWISS_CANTON_LABELS": SWISS_CANTON_LABELS,
        "PROVINCE_LABEL_OVERRIDES": PROVINCE_LABEL_OVERRIDES,
        "PROVINCE_LABELS": PROVINCE_LABELS,
        "region_suffix_matches": region_suffix_matches,
    },
)



#!/usr/bin/python3
""" """

import pytest

from ArWikiCats.translations.sports import games_labs


@pytest.mark.unit
def test_seasonal_labels_include_variants() -> None:
    labels = games_labs.SEASONAL_GAME_LABELS

    assert labels["olympic games"] == "الألعاب الأولمبية"
    assert labels["winter olympic games"] == "الألعاب الأولمبية الشتوية"
    assert labels["summer olympic games"] == "الألعاب الأولمبية الصيفية"
    assert labels["west olympic games"] == "الألعاب الأولمبية الغربية"



"""Party label helpers."""

from __future__ import annotations

from ...helps import logger
from ...translations import PARTIES
from .utils import resolve_suffix_template

PARTY_ROLE_SUFFIXES = {
    "candidates for member of parliament": "مرشحو %s لعضوية البرلمان",
    "candidates for member-of-parliament": "مرشحو %s لعضوية البرلمان",
    "candidates": "مرشحو %s",
    "leaders": "قادة %s",
    "politicians": "سياسيو %s",
    "members": "أعضاء %s",
    "state governors": "حكام ولايات من %s",
}


def get_parties_lab(party: str) -> str:
    """Return the Arabic label for ``party`` using known suffixes.

    Args:
        party: The party name to resolve.

    Returns:
        The resolved Arabic label or an empty string if the suffix is unknown.
    """

    normalized_party = party.strip()
    logger.debug(f"get_parties_lab {party=}")

    def _lookup(prefix: str) -> str:
        """Retrieve a party label by suffix prefix key."""
        return PARTIES.get(prefix, "")

    party_label = resolve_suffix_template(normalized_party, PARTY_ROLE_SUFFIXES, _lookup)

    if party_label:
        logger.info(f"get_parties_lab {party=}, {party_label=}")

    return party_label


__all__ = ["get_parties_lab"]



"""
Tests
"""

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats.new_resolvers.resolve_languages import resolve_languages_labels

test_data_0 = {
    "Arabic-language action films": "أفلام حركة باللغة العربية",
}

test_data = {
    "urdu-language comedy films": "أفلام كوميدية باللغة الأردية",
    "Arabic language activists": "ناشطون بلغة عربية",
    "Arabic-language biographical drama films": "أفلام سير ذاتية درامية باللغة العربية",
    "Arabic-language biographical films": "أفلام سير ذاتية باللغة العربية",
    "Arabic-language comedy-drama films": "أفلام كوميدية درامية باللغة العربية",
    "Arabic-language crime action films": "أفلام جريمة حركة باللغة العربية",
    "Arabic-language crime films": "أفلام جريمة باللغة العربية",
    "Arabic-language documentary films": "أفلام وثائقية باللغة العربية",
    "Arabic-language fantasy films": "أفلام فانتازيا باللغة العربية",
    "Arabic-language horror films": "أفلام رعب باللغة العربية",
    "Arabic-language musical films": "أفلام موسيقية باللغة العربية",
    "Arabic-language romance films": "أفلام رومانسية باللغة العربية",
    "Arabic-language romantic comedy-drama films": "أفلام رومانسية كوميدية درامية باللغة العربية",
    "Arabic-language thriller films": "أفلام إثارة باللغة العربية",
    "Arabic-language war films": "أفلام حربية باللغة العربية",
    "Bengali-language action adventure films": "أفلام حركة مغامرات باللغة البنغالية",
    "Bengali-language action comedy films": "أفلام حركة كوميدية باللغة البنغالية",
    "Bengali-language action drama films": "أفلام حركة درامية باللغة البنغالية",
    "Bengali-language action films": "أفلام حركة باللغة البنغالية",
    "Bengali-language adventure films": "أفلام مغامرات باللغة البنغالية",
    "Bengali-language adventure horror films": "أفلام مغامرات رعب باللغة البنغالية",
    "Bengali-language adventure thriller films": "أفلام مغامرات إثارة باللغة البنغالية",
    "Bengali-language animated films": "أفلام رسوم متحركة باللغة البنغالية",
    "Bengali-language anthology films": "أفلام أنثولوجيا باللغة البنغالية",
    "Bengali-language biographical drama films": "أفلام سير ذاتية درامية باللغة البنغالية",
    "Bengali-language biographical films": "أفلام سير ذاتية باللغة البنغالية",
    "Bengali-language comedy horror films": "أفلام كوميدية رعب باللغة البنغالية",
    "Bengali-language comedy mystery films": "أفلام كوميدية غموض باللغة البنغالية",
    "Bengali-language comedy-drama films": "أفلام كوميدية درامية باللغة البنغالية",
    "Bengali-language crime action films": "أفلام جريمة حركة باللغة البنغالية",
    "Bengali-language crime films": "أفلام جريمة باللغة البنغالية",
    "Bengali-language family drama films": "أفلام عائلية درامية باللغة البنغالية",
    "Bengali-language historical action films": "أفلام تاريخية حركة باللغة البنغالية",
    "Bengali-language historical drama films": "أفلام تاريخية درامية باللغة البنغالية",
    "Bengali-language historical films": "أفلام تاريخية باللغة البنغالية",
    "Bengali-language horror drama films": "أفلام رعب درامية باللغة البنغالية",
    "Bengali-language horror films": "أفلام رعب باللغة البنغالية",
    "Bengali-language horror thriller films": "أفلام رعب إثارة باللغة البنغالية",
    "Bengali-language independent films": "أفلام مستقلة باللغة البنغالية",
    "Bengali-language musical films": "أفلام موسيقية باللغة البنغالية",
    "Bengali-language mystery comedy-drama films": "أفلام غموض كوميدية درامية باللغة البنغالية",
    "Bengali-language mystery crime films": "أفلام غموض جريمة باللغة البنغالية",
    "Bengali-language mystery drama films": "أفلام غموض درامية باللغة البنغالية",
    "Bengali-language mystery films": "أفلام غموض باللغة البنغالية",
    "Bengali-language mystery thriller films": "أفلام غموض إثارة باللغة البنغالية",
    "Bengali-language romance films": "أفلام رومانسية باللغة البنغالية",
    "Bengali-language romantic action films": "أفلام رومانسية حركة باللغة البنغالية",
    "Bengali-language romantic comedy-drama films": "أفلام رومانسية كوميدية درامية باللغة البنغالية",
    "Bengali-language romantic thriller films": "أفلام رومانسية إثارة باللغة البنغالية",
    "Bengali-language short films": "أفلام قصيرة باللغة البنغالية",
    "Bengali-language sports films": "أفلام رياضية باللغة البنغالية",
    "Bengali-language spy thriller films": "أفلام تجسسية إثارة باللغة البنغالية",
    "Bengali-language thriller films": "أفلام إثارة باللغة البنغالية",
    "Bengali-language war films": "أفلام حربية باللغة البنغالية",
    "Bulgarian-language comedy-drama films": "أفلام كوميدية درامية باللغة البلغارية",
    "Burmese-language action films": "أفلام حركة باللغة البورمية",
    "Burmese-language comedy horror films": "أفلام كوميدية رعب باللغة البورمية",
    "Burmese-language comedy-drama films": "أفلام كوميدية درامية باللغة البورمية",
    "Burmese-language historical films": "أفلام تاريخية باللغة البورمية",
    "Burmese-language horror films": "أفلام رعب باللغة البورمية",
    "Burmese-language romance films": "أفلام رومانسية باللغة البورمية",
    "Burmese-language thriller films": "أفلام إثارة باللغة البورمية",
    "Cantonese-language action comedy films": "أفلام حركة كوميدية باللغة الكانتونية",
    "Cantonese-language action films": "أفلام حركة باللغة الكانتونية",
    "Cantonese-language comedy-drama films": "أفلام كوميدية درامية باللغة الكانتونية",
    "Cantonese-language crime films": "أفلام جريمة باللغة الكانتونية",
    "Cantonese-language fantasy films": "أفلام فانتازيا باللغة الكانتونية",
    "Cantonese-language historical drama films": "أفلام تاريخية درامية باللغة الكانتونية",
    "Cantonese-language horror films": "أفلام رعب باللغة الكانتونية",
    "Cantonese-language romance films": "أفلام رومانسية باللغة الكانتونية",
    "Cantonese-language thriller films": "أفلام إثارة باللغة الكانتونية",
    "Cantonese-language war films": "أفلام حربية باللغة الكانتونية",
    "Croatian-language biographical films": "أفلام سير ذاتية باللغة الكرواتية",
    "Croatian-language comedy-drama films": "أفلام كوميدية درامية باللغة الكرواتية",
    "Croatian-language crime films": "أفلام جريمة باللغة الكرواتية",
    "Croatian-language romance films": "أفلام رومانسية باللغة الكرواتية",
    "Croatian-language war films": "أفلام حربية باللغة الكرواتية",
    "Czech-language adventure films": "أفلام مغامرات باللغة التشيكية",
    "Czech-language biographical films": "أفلام سير ذاتية باللغة التشيكية",
    "Czech-language comedy-drama films": "أفلام كوميدية درامية باللغة التشيكية",
    "Czech-language crime films": "أفلام جريمة باللغة التشيكية",
    "Czech-language documentary films": "أفلام وثائقية باللغة التشيكية",
    "Czech-language fantasy films": "أفلام فانتازيا باللغة التشيكية",
    "Czech-language historical drama films": "أفلام تاريخية درامية باللغة التشيكية",
    "Czech-language historical films": "أفلام تاريخية باللغة التشيكية",
    "Czech-language horror films": "أفلام رعب باللغة التشيكية",
    "Czech-language musical films": "أفلام موسيقية باللغة التشيكية",
    "Czech-language romance films": "أفلام رومانسية باللغة التشيكية",
    "Czech-language science fiction adventure films": "أفلام خيال علمي مغامرات باللغة التشيكية",
    "Czech-language sports films": "أفلام رياضية باللغة التشيكية",
    "Czech-language thriller films": "أفلام إثارة باللغة التشيكية",
    "Czech-language war films": "أفلام حربية باللغة التشيكية",
    "Danish-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الدنماركية",
    "Danish-language adventure films": "أفلام مغامرات باللغة الدنماركية",
    "Danish-language biographical films": "أفلام سير ذاتية باللغة الدنماركية",
    "Danish-language comedy-drama films": "أفلام كوميدية درامية باللغة الدنماركية",
    "Danish-language crime films": "أفلام جريمة باللغة الدنماركية",
    "Danish-language documentary films": "أفلام وثائقية باللغة الدنماركية",
    "Danish-language horror films": "أفلام رعب باللغة الدنماركية",
    "Danish-language musical films": "أفلام موسيقية باللغة الدنماركية",
    "Danish-language romance films": "أفلام رومانسية باللغة الدنماركية",
    "Danish-language thriller films": "أفلام إثارة باللغة الدنماركية",
    "Danish-language war films": "أفلام حربية باللغة الدنماركية",
    "Dutch-language action comedy films": "أفلام حركة كوميدية باللغة الهولندية",
    "Dutch-language comedy-drama films": "أفلام كوميدية درامية باللغة الهولندية",
    "Dutch-language crime films": "أفلام جريمة باللغة الهولندية",
    "Dutch-language documentary films": "أفلام وثائقية باللغة الهولندية",
    "Dutch-language erotic drama films": "أفلام إغرائية درامية باللغة الهولندية",
    "Dutch-language erotic films": "أفلام إغرائية باللغة الهولندية",
    "Dutch-language fantasy films": "أفلام فانتازيا باللغة الهولندية",
    "Dutch-language historical drama films": "أفلام تاريخية درامية باللغة الهولندية",
    "Dutch-language historical films": "أفلام تاريخية باللغة الهولندية",
    "Dutch-language horror films": "أفلام رعب باللغة الهولندية",
    "Dutch-language musical films": "أفلام موسيقية باللغة الهولندية",
    "Dutch-language romance films": "أفلام رومانسية باللغة الهولندية",
    "Dutch-language sports films": "أفلام رياضية باللغة الهولندية",
    "Dutch-language thriller films": "أفلام إثارة باللغة الهولندية",
    "Dutch-language war films": "أفلام حربية باللغة الهولندية",
    "English-language action adventure films": "أفلام حركة مغامرات باللغة الإنجليزية",
    "English-language action comedy films": "أفلام حركة كوميدية باللغة الإنجليزية",
    "English-language action comedy-drama films": "أفلام حركة كوميدية درامية باللغة الإنجليزية",
    "English-language action drama films": "أفلام حركة درامية باللغة الإنجليزية",
    "English-language action films": "أفلام حركة باللغة الإنجليزية",
    "English-language action horror films": "أفلام حركة رعب باللغة الإنجليزية",
    "English-language action war films": "أفلام حركة حربية باللغة الإنجليزية",
    "English-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الإنجليزية",
    "English-language adventure comedy-drama films": "أفلام مغامرات كوميدية درامية باللغة الإنجليزية",
    "English-language adventure drama films": "أفلام مغامرات درامية باللغة الإنجليزية",
    "English-language adventure films": "أفلام مغامرات باللغة الإنجليزية",
    "English-language adventure thriller films": "أفلام مغامرات إثارة باللغة الإنجليزية",
    "English-language biographical drama films": "أفلام سير ذاتية درامية باللغة الإنجليزية",
    "English-language biographical films": "أفلام سير ذاتية باللغة الإنجليزية",
    "English-language buddy comedy films": "أفلام رفقاء كوميدية باللغة الإنجليزية",
    "English-language buddy comedy-drama films": "أفلام رفقاء كوميدية درامية باللغة الإنجليزية",
    "English-language buddy drama films": "أفلام رفقاء درامية باللغة الإنجليزية",
    "English-language Christmas comedy films": "أفلام عيد الميلاد كوميدية باللغة الإنجليزية",
    "English-language Christmas comedy-drama films": "أفلام عيد الميلاد كوميدية درامية باللغة الإنجليزية",
    "English-language Christmas drama films": "أفلام عيد الميلاد درامية باللغة الإنجليزية",
    "English-language Christmas films": "أفلام عيد الميلاد باللغة الإنجليزية",
    "English-language Christmas horror films": "أفلام عيد الميلاد رعب باللغة الإنجليزية",
    "English-language comedy horror films": "أفلام كوميدية رعب باللغة الإنجليزية",
    "English-language comedy mystery films": "أفلام كوميدية غموض باللغة الإنجليزية",
    "English-language comedy short films": "أفلام كوميدية قصيرة باللغة الإنجليزية",
    "English-language comedy-drama films": "أفلام كوميدية درامية باللغة الإنجليزية",
    "English-language comedy-drama short films": "أفلام كوميدية درامية قصيرة باللغة الإنجليزية",
    "English-language crime action films": "أفلام جريمة حركة باللغة الإنجليزية",
    "English-language crime comedy-drama films": "أفلام جريمة كوميدية درامية باللغة الإنجليزية",
    "English-language crime films": "أفلام جريمة باللغة الإنجليزية",
    "English-language documentary films": "أفلام وثائقية باللغة الإنجليزية",
    "English-language drama short films": "أفلام درامية قصيرة باللغة الإنجليزية",
    "English-language erotic drama films": "أفلام إغرائية درامية باللغة الإنجليزية",
    "English-language erotic films": "أفلام إغرائية باللغة الإنجليزية",
    "English-language erotic romance films": "أفلام إغرائية رومانسية باللغة الإنجليزية",
    "English-language fantasy action films": "أفلام فانتازيا حركة باللغة الإنجليزية",
    "English-language fantasy adventure films": "أفلام فانتازيا مغامرات باللغة الإنجليزية",
    "English-language fantasy comedy films": "أفلام فانتازيا كوميدية باللغة الإنجليزية",
    "English-language fantasy comedy-drama films": "أفلام فانتازيا كوميدية درامية باللغة الإنجليزية",
    "English-language fantasy drama films": "أفلام فانتازيا درامية باللغة الإنجليزية",
    "English-language fantasy films": "أفلام فانتازيا باللغة الإنجليزية",
    "English-language fantasy thriller films": "أفلام فانتازيا إثارة باللغة الإنجليزية",
    "English-language historical action films": "أفلام تاريخية حركة باللغة الإنجليزية",
    "English-language historical adventure films": "أفلام تاريخية مغامرات باللغة الإنجليزية",
    "English-language historical comedy films": "أفلام تاريخية كوميدية باللغة الإنجليزية",
    "English-language historical comedy-drama films": "أفلام تاريخية كوميدية درامية باللغة الإنجليزية",
    "English-language historical drama films": "أفلام تاريخية درامية باللغة الإنجليزية",
    "English-language historical films": "أفلام تاريخية باللغة الإنجليزية",
    "English-language historical horror films": "أفلام تاريخية رعب باللغة الإنجليزية",
    "English-language historical musical films": "أفلام تاريخية موسيقية باللغة الإنجليزية",
    "English-language historical romance films": "أفلام تاريخية رومانسية باللغة الإنجليزية",
    "English-language historical thriller films": "أفلام تاريخية إثارة باللغة الإنجليزية",
    "English-language horror drama films": "أفلام رعب درامية باللغة الإنجليزية",
    "English-language horror films": "أفلام رعب باللغة الإنجليزية",
    "English-language horror short films": "أفلام رعب قصيرة باللغة الإنجليزية",
    "English-language horror thriller films": "أفلام رعب إثارة باللغة الإنجليزية",
    "English-language independent films": "أفلام مستقلة باللغة الإنجليزية",
    "English-language musical comedy-drama films": "أفلام موسيقية كوميدية درامية باللغة الإنجليزية",
    "English-language musical fantasy films": "أفلام موسيقية فانتازيا باللغة الإنجليزية",
    "English-language musical films": "أفلام موسيقية باللغة الإنجليزية",
    "English-language mystery comedy-drama films": "أفلام غموض كوميدية درامية باللغة الإنجليزية",
    "English-language mystery drama films": "أفلام غموض درامية باللغة الإنجليزية",
    "English-language mystery films": "أفلام غموض باللغة الإنجليزية",
    "English-language mystery horror films": "أفلام غموض رعب باللغة الإنجليزية",
    "English-language mystery thriller films": "أفلام غموض إثارة باللغة الإنجليزية",
    "English-language political comedy films": "أفلام سياسية كوميدية باللغة الإنجليزية",
    "English-language political satire films": "أفلام سياسية هجائية باللغة الإنجليزية",
    "English-language romance films": "أفلام رومانسية باللغة الإنجليزية",
    "English-language romantic comedy-drama films": "أفلام رومانسية كوميدية درامية باللغة الإنجليزية",
    "English-language romantic fantasy films": "أفلام رومانسية فانتازيا باللغة الإنجليزية",
    "English-language romantic musical films": "أفلام رومانسية موسيقية باللغة الإنجليزية",
    "English-language romantic thriller films": "أفلام رومانسية إثارة باللغة الإنجليزية",
    "English-language science fiction adventure films": "أفلام خيال علمي مغامرات باللغة الإنجليزية",
    "English-language science fiction comedy films": "أفلام خيال علمي كوميدية باللغة الإنجليزية",
    "English-language science fiction comedy-drama films": "أفلام خيال علمي كوميدية درامية باللغة الإنجليزية",
    "English-language science fiction drama films": "أفلام خيال علمي درامية باللغة الإنجليزية",
    "English-language science fiction horror films": "أفلام خيال علمي رعب باللغة الإنجليزية",
    "English-language science fiction romance films": "أفلام خيال علمي رومانسية باللغة الإنجليزية",
    "English-language sex comedy films": "أفلام جنسية كوميدية باللغة الإنجليزية",
    "English-language sex comedy-drama films": "أفلام جنسية كوميدية درامية باللغة الإنجليزية",
    "English-language short documentary films": "أفلام قصيرة وثائقية باللغة الإنجليزية",
    "English-language short films": "أفلام قصيرة باللغة الإنجليزية",
    "English-language sports comedy films": "أفلام رياضية كوميدية باللغة الإنجليزية",
    "English-language sports comedy-drama films": "أفلام رياضية كوميدية درامية باللغة الإنجليزية",
    "English-language sports films": "أفلام رياضية باللغة الإنجليزية",
    "English-language spy action films": "أفلام تجسسية حركة باللغة الإنجليزية",
    "English-language spy comedy films": "أفلام تجسسية كوميدية باللغة الإنجليزية",
    "English-language spy drama films": "أفلام تجسسية درامية باللغة الإنجليزية",
    "English-language spy thriller films": "أفلام تجسسية إثارة باللغة الإنجليزية",
    "English-language teen comedy films": "أفلام مراهقة كوميدية باللغة الإنجليزية",
    "English-language teen drama films": "أفلام مراهقة درامية باللغة الإنجليزية",
    "English-language teen films": "أفلام مراهقة باللغة الإنجليزية",
    "English-language thriller films": "أفلام إثارة باللغة الإنجليزية",
    "English-language war adventure films": "أفلام حربية مغامرات باللغة الإنجليزية",
    "English-language war comedy films": "أفلام حربية كوميدية باللغة الإنجليزية",
    "English-language war comedy-drama films": "أفلام حربية كوميدية درامية باللغة الإنجليزية",
    "English-language war films": "أفلام حربية باللغة الإنجليزية",
    "English-language war romance films": "أفلام حربية رومانسية باللغة الإنجليزية",
    "Estonian-language comedy-drama films": "أفلام كوميدية درامية باللغة الإستونية",
    "Finnish-language action films": "أفلام حركة باللغة الفنلندية",
    "Finnish-language biographical films": "أفلام سير ذاتية باللغة الفنلندية",
    "Finnish-language comedy horror films": "أفلام كوميدية رعب باللغة الفنلندية",
    "Finnish-language comedy-drama films": "أفلام كوميدية درامية باللغة الفنلندية",
    "Finnish-language crime films": "أفلام جريمة باللغة الفنلندية",
    "Finnish-language documentary films": "أفلام وثائقية باللغة الفنلندية",
    "Finnish-language erotic drama films": "أفلام إغرائية درامية باللغة الفنلندية",
    "Finnish-language erotic films": "أفلام إغرائية باللغة الفنلندية",
    "Finnish-language fantasy adventure films": "أفلام فانتازيا مغامرات باللغة الفنلندية",
    "Finnish-language fantasy films": "أفلام فانتازيا باللغة الفنلندية",
    "Finnish-language historical films": "أفلام تاريخية باللغة الفنلندية",
    "Finnish-language horror films": "أفلام رعب باللغة الفنلندية",
    "Finnish-language thriller films": "أفلام إثارة باللغة الفنلندية",
    "Finnish-language war films": "أفلام حربية باللغة الفنلندية",
    "French-language action comedy films": "أفلام حركة كوميدية باللغة الفرنسية",
    "French-language action films": "أفلام حركة باللغة الفرنسية",
    "French-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الفرنسية",
    "French-language adventure drama films": "أفلام مغامرات درامية باللغة الفرنسية",
    "French-language adventure films": "أفلام مغامرات باللغة الفرنسية",
    "French-language biographical drama films": "أفلام سير ذاتية درامية باللغة الفرنسية",
    "French-language biographical films": "أفلام سير ذاتية باللغة الفرنسية",
    "French-language comedy horror films": "أفلام كوميدية رعب باللغة الفرنسية",
    "French-language comedy mystery films": "أفلام كوميدية غموض باللغة الفرنسية",
    "French-language comedy-drama films": "أفلام كوميدية درامية باللغة الفرنسية",
    "French-language crime films": "أفلام جريمة باللغة الفرنسية",
    "French-language documentary films": "أفلام وثائقية باللغة الفرنسية",
    "French-language erotic drama films": "أفلام إغرائية درامية باللغة الفرنسية",
    "French-language erotic films": "أفلام إغرائية باللغة الفرنسية",
    "French-language fantasy films": "أفلام فانتازيا باللغة الفرنسية",
    "French-language historical adventure films": "أفلام تاريخية مغامرات باللغة الفرنسية",
    "French-language historical comedy films": "أفلام تاريخية كوميدية باللغة الفرنسية",
    "French-language historical drama films": "أفلام تاريخية درامية باللغة الفرنسية",
    "French-language historical films": "أفلام تاريخية باللغة الفرنسية",
    "French-language horror films": "أفلام رعب باللغة الفرنسية",
    "French-language independent films": "أفلام مستقلة باللغة الفرنسية",
    "French-language musical films": "أفلام موسيقية باللغة الفرنسية",
    "French-language mystery films": "أفلام غموض باللغة الفرنسية",
    "French-language mystery thriller films": "أفلام غموض إثارة باللغة الفرنسية",
    "French-language romance films": "أفلام رومانسية باللغة الفرنسية",
    "French-language sex comedy films": "أفلام جنسية كوميدية باللغة الفرنسية",
    "French-language sex comedy-drama films": "أفلام جنسية كوميدية درامية باللغة الفرنسية",
    "French-language short documentary films": "أفلام قصيرة وثائقية باللغة الفرنسية",
    "French-language short films": "أفلام قصيرة باللغة الفرنسية",
    "French-language sports comedy films": "أفلام رياضية كوميدية باللغة الفرنسية",
    "French-language sports films": "أفلام رياضية باللغة الفرنسية",
    "French-language thriller films": "أفلام إثارة باللغة الفرنسية",
    "French-language war adventure films": "أفلام حربية مغامرات باللغة الفرنسية",
    "French-language war comedy films": "أفلام حربية كوميدية باللغة الفرنسية",
    "French-language war films": "أفلام حربية باللغة الفرنسية",
    "German-language action comedy films": "أفلام حركة كوميدية باللغة الألمانية",
    "German-language action films": "أفلام حركة باللغة الألمانية",
    "German-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الألمانية",
    "German-language adventure drama films": "أفلام مغامرات درامية باللغة الألمانية",
    "German-language adventure films": "أفلام مغامرات باللغة الألمانية",
    "German-language biographical drama films": "أفلام سير ذاتية درامية باللغة الألمانية",
    "German-language biographical films": "أفلام سير ذاتية باللغة الألمانية",
    "German-language comedy horror films": "أفلام كوميدية رعب باللغة الألمانية",
    "German-language comedy-drama films": "أفلام كوميدية درامية باللغة الألمانية",
    "German-language crime films": "أفلام جريمة باللغة الألمانية",
    "German-language documentary films": "أفلام وثائقية باللغة الألمانية",
    "German-language erotic drama films": "أفلام إغرائية درامية باللغة الألمانية",
    "German-language erotic films": "أفلام إغرائية باللغة الألمانية",
    "German-language fantasy films": "أفلام فانتازيا باللغة الألمانية",
    "German-language historical adventure films": "أفلام تاريخية مغامرات باللغة الألمانية",
    "German-language historical comedy films": "أفلام تاريخية كوميدية باللغة الألمانية",
    "German-language historical drama films": "أفلام تاريخية درامية باللغة الألمانية",
    "German-language historical films": "أفلام تاريخية باللغة الألمانية",
    "German-language historical musical films": "أفلام تاريخية موسيقية باللغة الألمانية",
    "German-language horror films": "أفلام رعب باللغة الألمانية",
    "German-language independent films": "أفلام مستقلة باللغة الألمانية",
    "German-language musical films": "أفلام موسيقية باللغة الألمانية",
    "German-language mystery films": "أفلام غموض باللغة الألمانية",
    "German-language mystery thriller films": "أفلام غموض إثارة باللغة الألمانية",
    "German-language romance films": "أفلام رومانسية باللغة الألمانية",
    "German-language sex comedy films": "أفلام جنسية كوميدية باللغة الألمانية",
    "German-language sports comedy films": "أفلام رياضية كوميدية باللغة الألمانية",
    "German-language sports films": "أفلام رياضية باللغة الألمانية",
    "German-language spy drama films": "أفلام تجسسية درامية باللغة الألمانية",
    "German-language spy thriller films": "أفلام تجسسية إثارة باللغة الألمانية",
    "German-language thriller films": "أفلام إثارة باللغة الألمانية",
    "German-language war comedy films": "أفلام حربية كوميدية باللغة الألمانية",
    "German-language war films": "أفلام حربية باللغة الألمانية",
    "Greek-language adventure films": "أفلام مغامرات باللغة اليونانية",
    "Greek-language biographical films": "أفلام سير ذاتية باللغة اليونانية",
    "Greek-language comedy-drama films": "أفلام كوميدية درامية باللغة اليونانية",
    "Greek-language crime films": "أفلام جريمة باللغة اليونانية",
    "Greek-language horror films": "أفلام رعب باللغة اليونانية",
    "Greek-language musical films": "أفلام موسيقية باللغة اليونانية",
    "Greek-language romance films": "أفلام رومانسية باللغة اليونانية",
    "Greek-language thriller films": "أفلام إثارة باللغة اليونانية",
    "Greek-language war films": "أفلام حربية باللغة اليونانية",
    "Hebrew-language comedy-drama films": "أفلام كوميدية درامية باللغة العبرية",
    "Hebrew-language crime films": "أفلام جريمة باللغة العبرية",
    "Hebrew-language documentary films": "أفلام وثائقية باللغة العبرية",
    "Hebrew-language romance films": "أفلام رومانسية باللغة العبرية",
    "Hebrew-language thriller films": "أفلام إثارة باللغة العبرية",
    "Hebrew-language war films": "أفلام حربية باللغة العبرية",
    "Hindi-language action adventure films": "أفلام حركة مغامرات باللغة الهندية",
    "Hindi-language action comedy films": "أفلام حركة كوميدية باللغة الهندية",
    "Hindi-language action drama films": "أفلام حركة درامية باللغة الهندية",
    "Hindi-language action films": "أفلام حركة باللغة الهندية",
    "Hindi-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الهندية",
    "Hindi-language adventure films": "أفلام مغامرات باللغة الهندية",
    "Hindi-language biographical drama films": "أفلام سير ذاتية درامية باللغة الهندية",
    "Hindi-language biographical films": "أفلام سير ذاتية باللغة الهندية",
    "Hindi-language comedy horror films": "أفلام كوميدية رعب باللغة الهندية",
    "Hindi-language comedy-drama films": "أفلام كوميدية درامية باللغة الهندية",
    "Hindi-language crime action films": "أفلام جريمة حركة باللغة الهندية",
    "Hindi-language crime films": "أفلام جريمة باللغة الهندية",
    "Hindi-language fantasy comedy films": "أفلام فانتازيا كوميدية باللغة الهندية",
    "Hindi-language fantasy films": "أفلام فانتازيا باللغة الهندية",
    "Hindi-language horror films": "أفلام رعب باللغة الهندية",
    "Hindi-language horror thriller films": "أفلام رعب إثارة باللغة الهندية",
    "Hindi-language mystery films": "أفلام غموض باللغة الهندية",
    "Hindi-language mystery thriller films": "أفلام غموض إثارة باللغة الهندية",
    "Hindi-language romance films": "أفلام رومانسية باللغة الهندية",
    "Hindi-language romantic thriller films": "أفلام رومانسية إثارة باللغة الهندية",
    "Hindi-language sports films": "أفلام رياضية باللغة الهندية",
    "Hindi-language thriller films": "أفلام إثارة باللغة الهندية",
    "Hungarian-language adventure films": "أفلام مغامرات باللغة المجرية",
    "Hungarian-language biographical films": "أفلام سير ذاتية باللغة المجرية",
    "Hungarian-language comedy-drama films": "أفلام كوميدية درامية باللغة المجرية",
    "Hungarian-language crime films": "أفلام جريمة باللغة المجرية",
    "Hungarian-language historical drama films": "أفلام تاريخية درامية باللغة المجرية",
    "Hungarian-language historical films": "أفلام تاريخية باللغة المجرية",
    "Hungarian-language musical films": "أفلام موسيقية باللغة المجرية",
    "Hungarian-language romance films": "أفلام رومانسية باللغة المجرية",
    "Hungarian-language thriller films": "أفلام إثارة باللغة المجرية",
    "Hungarian-language war films": "أفلام حربية باللغة المجرية",
    "Icelandic-language comedy-drama films": "أفلام كوميدية درامية باللغة الآيسلندية",
    "Icelandic-language documentary films": "أفلام وثائقية باللغة الآيسلندية",
    "Indonesian-language action films": "أفلام حركة باللغة الإندونيسية",
    "Indonesian-language biographical films": "أفلام سير ذاتية باللغة الإندونيسية",
    "Indonesian-language comedy-drama films": "أفلام كوميدية درامية باللغة الإندونيسية",
    "Indonesian-language horror films": "أفلام رعب باللغة الإندونيسية",
    "Indonesian-language romance films": "أفلام رومانسية باللغة الإندونيسية",
    "Indonesian-language thriller films": "أفلام إثارة باللغة الإندونيسية",
    "Italian-language action adventure films": "أفلام حركة مغامرات باللغة الإيطالية",
    "Italian-language action films": "أفلام حركة باللغة الإيطالية",
    "Italian-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الإيطالية",
    "Italian-language adventure films": "أفلام مغامرات باللغة الإيطالية",
    "Italian-language biographical drama films": "أفلام سير ذاتية درامية باللغة الإيطالية",
    "Italian-language biographical films": "أفلام سير ذاتية باللغة الإيطالية",
    "Italian-language buddy comedy films": "أفلام رفقاء كوميدية باللغة الإيطالية",
    "Italian-language comedy-drama films": "أفلام كوميدية درامية باللغة الإيطالية",
    "Italian-language crime films": "أفلام جريمة باللغة الإيطالية",
    "Italian-language documentary films": "أفلام وثائقية باللغة الإيطالية",
    "Italian-language erotic drama films": "أفلام إغرائية درامية باللغة الإيطالية",
    "Italian-language erotic films": "أفلام إغرائية باللغة الإيطالية",
    "Italian-language fantasy adventure films": "أفلام فانتازيا مغامرات باللغة الإيطالية",
    "Italian-language fantasy films": "أفلام فانتازيا باللغة الإيطالية",
    "Italian-language historical adventure films": "أفلام تاريخية مغامرات باللغة الإيطالية",
    "Italian-language historical comedy films": "أفلام تاريخية كوميدية باللغة الإيطالية",
    "Italian-language historical drama films": "أفلام تاريخية درامية باللغة الإيطالية",
    "Italian-language historical films": "أفلام تاريخية باللغة الإيطالية",
    "Italian-language horror films": "أفلام رعب باللغة الإيطالية",
    "Italian-language independent films": "أفلام مستقلة باللغة الإيطالية",
    "Italian-language musical films": "أفلام موسيقية باللغة الإيطالية",
    "Italian-language mystery films": "أفلام غموض باللغة الإيطالية",
    "Italian-language mystery thriller films": "أفلام غموض إثارة باللغة الإيطالية",
    "Italian-language romance films": "أفلام رومانسية باللغة الإيطالية",
    "Italian-language science fiction adventure films": "أفلام خيال علمي مغامرات باللغة الإيطالية",
    "Italian-language science fiction comedy films": "أفلام خيال علمي كوميدية باللغة الإيطالية",
    "Italian-language sex comedy films": "أفلام جنسية كوميدية باللغة الإيطالية",
    "Italian-language sports comedy films": "أفلام رياضية كوميدية باللغة الإيطالية",
    "Italian-language sports films": "أفلام رياضية باللغة الإيطالية",
    "Italian-language spy comedy films": "أفلام تجسسية كوميدية باللغة الإيطالية",
    "Italian-language thriller films": "أفلام إثارة باللغة الإيطالية",
    "Italian-language war comedy films": "أفلام حربية كوميدية باللغة الإيطالية",
    "Italian-language war films": "أفلام حربية باللغة الإيطالية",
    "Japanese-language action comedy films": "أفلام حركة كوميدية باللغة اليابانية",
    "Japanese-language action films": "أفلام حركة باللغة اليابانية",
    "Japanese-language adventure films": "أفلام مغامرات باللغة اليابانية",
    "Japanese-language biographical films": "أفلام سير ذاتية باللغة اليابانية",
    "Japanese-language comedy-drama films": "أفلام كوميدية درامية باللغة اليابانية",
    "Japanese-language crime films": "أفلام جريمة باللغة اليابانية",
    "Japanese-language documentary films": "أفلام وثائقية باللغة اليابانية",
    "Japanese-language erotic drama films": "أفلام إغرائية درامية باللغة اليابانية",
    "Japanese-language erotic films": "أفلام إغرائية باللغة اليابانية",
    "Japanese-language fantasy films": "أفلام فانتازيا باللغة اليابانية",
    "Japanese-language historical drama films": "أفلام تاريخية درامية باللغة اليابانية",
    "Japanese-language historical films": "أفلام تاريخية باللغة اليابانية",
    "Japanese-language horror films": "أفلام رعب باللغة اليابانية",
    "Japanese-language musical films": "أفلام موسيقية باللغة اليابانية",
    "Japanese-language mystery films": "أفلام غموض باللغة اليابانية",
    "Japanese-language mystery thriller films": "أفلام غموض إثارة باللغة اليابانية",
    "Japanese-language romance films": "أفلام رومانسية باللغة اليابانية",
    "Japanese-language sex comedy films": "أفلام جنسية كوميدية باللغة اليابانية",
    "Japanese-language sports films": "أفلام رياضية باللغة اليابانية",
    "Japanese-language thriller films": "أفلام إثارة باللغة اليابانية",
    "Japanese-language war films": "أفلام حربية باللغة اليابانية",
    "Kannada-language action comedy films": "أفلام حركة كوميدية باللغة الكنادية",
    "Kannada-language action films": "أفلام حركة باللغة الكنادية",
    "Kannada-language comedy-drama films": "أفلام كوميدية درامية باللغة الكنادية",
    "Kannada-language mystery films": "أفلام غموض باللغة الكنادية",
    "Kannada-language mystery thriller films": "أفلام غموض إثارة باللغة الكنادية",
    "Kannada-language romance films": "أفلام رومانسية باللغة الكنادية",
    "Kannada-language thriller films": "أفلام إثارة باللغة الكنادية",
    "Korean-language action adventure films": "أفلام حركة مغامرات باللغة الكورية",
    "Korean-language action comedy films": "أفلام حركة كوميدية باللغة الكورية",
    "Korean-language action films": "أفلام حركة باللغة الكورية",
    "Korean-language action horror films": "أفلام حركة رعب باللغة الكورية",
    "Korean-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الكورية",
    "Korean-language biographical films": "أفلام سير ذاتية باللغة الكورية",
    "Korean-language comedy horror films": "أفلام كوميدية رعب باللغة الكورية",
    "Korean-language comedy-drama films": "أفلام كوميدية درامية باللغة الكورية",
    "Korean-language crime action films": "أفلام جريمة حركة باللغة الكورية",
    "Korean-language crime films": "أفلام جريمة باللغة الكورية",
    "Korean-language documentary films": "أفلام وثائقية باللغة الكورية",
    "Korean-language erotic drama films": "أفلام إغرائية درامية باللغة الكورية",
    "Korean-language erotic films": "أفلام إغرائية باللغة الكورية",
    "Korean-language fantasy films": "أفلام فانتازيا باللغة الكورية",
    "Korean-language historical drama films": "أفلام تاريخية درامية باللغة الكورية",
    "Korean-language historical films": "أفلام تاريخية باللغة الكورية",
    "Korean-language horror films": "أفلام رعب باللغة الكورية",
    "Korean-language musical films": "أفلام موسيقية باللغة الكورية",
    "Korean-language mystery films": "أفلام غموض باللغة الكورية",
    "Korean-language mystery thriller films": "أفلام غموض إثارة باللغة الكورية",
    "Korean-language romance films": "أفلام رومانسية باللغة الكورية",
    "Korean-language sports films": "أفلام رياضية باللغة الكورية",
    "Korean-language thriller films": "أفلام إثارة باللغة الكورية",
    "Korean-language war films": "أفلام حربية باللغة الكورية",
    "Malayalam-language action comedy films": "أفلام حركة كوميدية باللغة الماليالامية",
    "Malayalam-language comedy-drama films": "أفلام كوميدية درامية باللغة الماليالامية",
    "Malayalam-language romance films": "أفلام رومانسية باللغة الماليالامية",
    "Malayalam-language thriller films": "أفلام إثارة باللغة الماليالامية",
    "Marathi-language action comedy films": "أفلام حركة كوميدية باللغة الماراثية",
    "Marathi-language action drama films": "أفلام حركة درامية باللغة الماراثية",
    "Marathi-language action films": "أفلام حركة باللغة الماراثية",
    "Marathi-language adventure films": "أفلام مغامرات باللغة الماراثية",
    "Marathi-language biographical films": "أفلام سير ذاتية باللغة الماراثية",
    "Marathi-language comedy horror films": "أفلام كوميدية رعب باللغة الماراثية",
    "Marathi-language crime films": "أفلام جريمة باللغة الماراثية",
    "Marathi-language family drama films": "أفلام عائلية درامية باللغة الماراثية",
    "Marathi-language fantasy thriller films": "أفلام فانتازيا إثارة باللغة الماراثية",
    "Marathi-language historical films": "أفلام تاريخية باللغة الماراثية",
    "Marathi-language musical films": "أفلام موسيقية باللغة الماراثية",
    "Marathi-language period drama films": "أفلام حقبية درامية باللغة الماراثية",
    "Marathi-language romance films": "أفلام رومانسية باللغة الماراثية",
    "Marathi-language short films": "أفلام قصيرة باللغة الماراثية",
    "Marathi-language supernatural horror films": "أفلام خارقة للطبيعة رعب باللغة الماراثية",
    "Marathi-language thriller films": "أفلام إثارة باللغة الماراثية",
    "Norwegian-language comedy-drama films": "أفلام كوميدية درامية باللغة النرويجية",
    "Norwegian-language crime films": "أفلام جريمة باللغة النرويجية",
    "Norwegian-language documentary films": "أفلام وثائقية باللغة النرويجية",
    "Norwegian-language horror films": "أفلام رعب باللغة النرويجية",
    "Norwegian-language romance films": "أفلام رومانسية باللغة النرويجية",
    "Norwegian-language thriller films": "أفلام إثارة باللغة النرويجية",
    "Norwegian-language war films": "أفلام حربية باللغة النرويجية",
    "Persian-language adventure films": "أفلام مغامرات باللغة الفارسية",
    "Persian-language biographical films": "أفلام سير ذاتية باللغة الفارسية",
    "Persian-language comedy-drama films": "أفلام كوميدية درامية باللغة الفارسية",
    "Persian-language crime films": "أفلام جريمة باللغة الفارسية",
    "Persian-language documentary films": "أفلام وثائقية باللغة الفارسية",
    "Persian-language horror films": "أفلام رعب باللغة الفارسية",
    "Persian-language romance films": "أفلام رومانسية باللغة الفارسية",
    "Persian-language war films": "أفلام حربية باللغة الفارسية",
    "Polish-language adventure films": "أفلام مغامرات باللغة البولندية",
    "Polish-language biographical films": "أفلام سير ذاتية باللغة البولندية",
    "Polish-language comedy-drama films": "أفلام كوميدية درامية باللغة البولندية",
    "Polish-language crime films": "أفلام جريمة باللغة البولندية",
    "Polish-language documentary films": "أفلام وثائقية باللغة البولندية",
    "Polish-language fantasy films": "أفلام فانتازيا باللغة البولندية",
    "Polish-language historical drama films": "أفلام تاريخية درامية باللغة البولندية",
    "Polish-language historical films": "أفلام تاريخية باللغة البولندية",
    "Polish-language musical films": "أفلام موسيقية باللغة البولندية",
    "Polish-language romance films": "أفلام رومانسية باللغة البولندية",
    "Polish-language sports films": "أفلام رياضية باللغة البولندية",
    "Polish-language thriller films": "أفلام إثارة باللغة البولندية",
    "Polish-language war films": "أفلام حربية باللغة البولندية",
    "Portuguese-language action adventure films": "أفلام حركة مغامرات باللغة البرتغالية",
    "Portuguese-language action comedy films": "أفلام حركة كوميدية باللغة البرتغالية",
    "Portuguese-language action films": "أفلام حركة باللغة البرتغالية",
    "Portuguese-language adventure films": "أفلام مغامرات باللغة البرتغالية",
    "Portuguese-language biographical drama films": "أفلام سير ذاتية درامية باللغة البرتغالية",
    "Portuguese-language biographical films": "أفلام سير ذاتية باللغة البرتغالية",
    "Portuguese-language comedy-drama films": "أفلام كوميدية درامية باللغة البرتغالية",
    "Portuguese-language crime films": "أفلام جريمة باللغة البرتغالية",
    "Portuguese-language documentary films": "أفلام وثائقية باللغة البرتغالية",
    "Portuguese-language fantasy films": "أفلام فانتازيا باللغة البرتغالية",
    "Portuguese-language historical drama films": "أفلام تاريخية درامية باللغة البرتغالية",
    "Portuguese-language historical films": "أفلام تاريخية باللغة البرتغالية",
    "Portuguese-language horror films": "أفلام رعب باللغة البرتغالية",
    "Portuguese-language musical films": "أفلام موسيقية باللغة البرتغالية",
    "Portuguese-language mystery films": "أفلام غموض باللغة البرتغالية",
    "Portuguese-language romance films": "أفلام رومانسية باللغة البرتغالية",
    "Portuguese-language sports films": "أفلام رياضية باللغة البرتغالية",
    "Portuguese-language thriller films": "أفلام إثارة باللغة البرتغالية",
    "Romanian-language action comedy films": "أفلام حركة كوميدية باللغة الرومانية",
    "Romanian-language action films": "أفلام حركة باللغة الرومانية",
    "Romanian-language comedy-drama films": "أفلام كوميدية درامية باللغة الرومانية",
    "Romanian-language crime films": "أفلام جريمة باللغة الرومانية",
    "Romanian-language fantasy films": "أفلام فانتازيا باللغة الرومانية",
    "Romanian-language historical drama films": "أفلام تاريخية درامية باللغة الرومانية",
    "Romanian-language historical films": "أفلام تاريخية باللغة الرومانية",
    "Romanian-language thriller films": "أفلام إثارة باللغة الرومانية",
    "Romanian-language war films": "أفلام حربية باللغة الرومانية",
    "Russian-language action adventure films": "أفلام حركة مغامرات باللغة الروسية",
    "Russian-language action drama films": "أفلام حركة درامية باللغة الروسية",
    "Russian-language action films": "أفلام حركة باللغة الروسية",
    "Russian-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الروسية",
    "Russian-language adventure drama films": "أفلام مغامرات درامية باللغة الروسية",
    "Russian-language adventure films": "أفلام مغامرات باللغة الروسية",
    "Russian-language adventure thriller films": "أفلام مغامرات إثارة باللغة الروسية",
    "Russian-language biographical drama films": "أفلام سير ذاتية درامية باللغة الروسية",
    "Russian-language biographical films": "أفلام سير ذاتية باللغة الروسية",
    "Russian-language comedy short films": "أفلام كوميدية قصيرة باللغة الروسية",
    "Russian-language comedy-drama films": "أفلام كوميدية درامية باللغة الروسية",
    "Russian-language crime action films": "أفلام جريمة حركة باللغة الروسية",
    "Russian-language crime films": "أفلام جريمة باللغة الروسية",
    "Russian-language documentary films": "أفلام وثائقية باللغة الروسية",
    "Russian-language fantasy adventure films": "أفلام فانتازيا مغامرات باللغة الروسية",
    "Russian-language fantasy comedy films": "أفلام فانتازيا كوميدية باللغة الروسية",
    "Russian-language fantasy drama films": "أفلام فانتازيا درامية باللغة الروسية",
    "Russian-language fantasy films": "أفلام فانتازيا باللغة الروسية",
    "Russian-language historical action films": "أفلام تاريخية حركة باللغة الروسية",
    "Russian-language historical adventure films": "أفلام تاريخية مغامرات باللغة الروسية",
    "Russian-language historical comedy films": "أفلام تاريخية كوميدية باللغة الروسية",
    "Russian-language historical drama films": "أفلام تاريخية درامية باللغة الروسية",
    "Russian-language historical films": "أفلام تاريخية باللغة الروسية",
    "Russian-language historical musical films": "أفلام تاريخية موسيقية باللغة الروسية",
    "Russian-language horror films": "أفلام رعب باللغة الروسية",
    "Russian-language horror thriller films": "أفلام رعب إثارة باللغة الروسية",
    "Russian-language independent films": "أفلام مستقلة باللغة الروسية",
    "Russian-language musical comedy-drama films": "أفلام موسيقية كوميدية درامية باللغة الروسية",
    "Russian-language musical films": "أفلام موسيقية باللغة الروسية",
    "Russian-language mystery drama films": "أفلام غموض درامية باللغة الروسية",
    "Russian-language mystery films": "أفلام غموض باللغة الروسية",
    "Russian-language mystery thriller films": "أفلام غموض إثارة باللغة الروسية",
    "Russian-language romance films": "أفلام رومانسية باللغة الروسية",
    "Russian-language romantic comedy-drama films": "أفلام رومانسية كوميدية درامية باللغة الروسية",
    "Russian-language romantic musical films": "أفلام رومانسية موسيقية باللغة الروسية",
    "Russian-language science fiction adventure films": "أفلام خيال علمي مغامرات باللغة الروسية",
    "Russian-language science fiction comedy films": "أفلام خيال علمي كوميدية باللغة الروسية",
    "Russian-language science fiction drama films": "أفلام خيال علمي درامية باللغة الروسية",
    "Russian-language science fiction horror films": "أفلام خيال علمي رعب باللغة الروسية",
    "Russian-language short films": "أفلام قصيرة باللغة الروسية",
    "Russian-language sports films": "أفلام رياضية باللغة الروسية",
    "Russian-language thriller films": "أفلام إثارة باللغة الروسية",
    "Russian-language war adventure films": "أفلام حربية مغامرات باللغة الروسية",
    "Russian-language war comedy films": "أفلام حربية كوميدية باللغة الروسية",
    "Russian-language war films": "أفلام حربية باللغة الروسية",
    "Serbian-language biographical films": "أفلام سير ذاتية باللغة الصربية",
    "Serbian-language comedy-drama films": "أفلام كوميدية درامية باللغة الصربية",
    "Serbian-language documentary films": "أفلام وثائقية باللغة الصربية",
    "Serbian-language historical drama films": "أفلام تاريخية درامية باللغة الصربية",
    "Serbian-language horror films": "أفلام رعب باللغة الصربية",
    "Serbian-language romance films": "أفلام رومانسية باللغة الصربية",
    "Serbian-language war films": "أفلام حربية باللغة الصربية",
    "Sinhala-language romance films": "أفلام رومانسية باللغة السنهالية",
    "Sinhala-language thriller films": "أفلام إثارة باللغة السنهالية",
    "Spanish-language action adventure films": "أفلام حركة مغامرات باللغة الإسبانية",
    "Spanish-language action comedy films": "أفلام حركة كوميدية باللغة الإسبانية",
    "Spanish-language action drama films": "أفلام حركة درامية باللغة الإسبانية",
    "Spanish-language action films": "أفلام حركة باللغة الإسبانية",
    "Spanish-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الإسبانية",
    "Spanish-language adventure drama films": "أفلام مغامرات درامية باللغة الإسبانية",
    "Spanish-language adventure films": "أفلام مغامرات باللغة الإسبانية",
    "Spanish-language biographical drama films": "أفلام سير ذاتية درامية باللغة الإسبانية",
    "Spanish-language comedy horror films": "أفلام كوميدية رعب باللغة الإسبانية",
    "Spanish-language comedy mystery films": "أفلام كوميدية غموض باللغة الإسبانية",
    "Spanish-language comedy-drama films": "أفلام كوميدية درامية باللغة الإسبانية",
    "Spanish-language crime films": "أفلام جريمة باللغة الإسبانية",
    "Spanish-language documentary films": "أفلام وثائقية باللغة الإسبانية",
    "Spanish-language erotic drama films": "أفلام إغرائية درامية باللغة الإسبانية",
    "Spanish-language erotic films": "أفلام إغرائية باللغة الإسبانية",
    "Spanish-language fantasy adventure films": "أفلام فانتازيا مغامرات باللغة الإسبانية",
    "Spanish-language fantasy films": "أفلام فانتازيا باللغة الإسبانية",
    "Spanish-language historical adventure films": "أفلام تاريخية مغامرات باللغة الإسبانية",
    "Spanish-language historical comedy films": "أفلام تاريخية كوميدية باللغة الإسبانية",
    "Spanish-language historical drama films": "أفلام تاريخية درامية باللغة الإسبانية",
    "Spanish-language historical films": "أفلام تاريخية باللغة الإسبانية",
    "Spanish-language historical romance films": "أفلام تاريخية رومانسية باللغة الإسبانية",
    "Spanish-language horror drama films": "أفلام رعب درامية باللغة الإسبانية",
    "Spanish-language horror films": "أفلام رعب باللغة الإسبانية",
    "Spanish-language independent films": "أفلام مستقلة باللغة الإسبانية",
    "Spanish-language musical films": "أفلام موسيقية باللغة الإسبانية",
    "Spanish-language mystery films": "أفلام غموض باللغة الإسبانية",
    "Spanish-language mystery thriller films": "أفلام غموض إثارة باللغة الإسبانية",
    "Spanish-language romance films": "أفلام رومانسية باللغة الإسبانية",
    "Spanish-language romantic comedy-drama films": "أفلام رومانسية كوميدية درامية باللغة الإسبانية",
    "Spanish-language romantic musical films": "أفلام رومانسية موسيقية باللغة الإسبانية",
    "Spanish-language science fiction adventure films": "أفلام خيال علمي مغامرات باللغة الإسبانية",
    "Spanish-language science fiction comedy films": "أفلام خيال علمي كوميدية باللغة الإسبانية",
    "Spanish-language sex comedy films": "أفلام جنسية كوميدية باللغة الإسبانية",
    "Spanish-language sex comedy-drama films": "أفلام جنسية كوميدية درامية باللغة الإسبانية",
    "Spanish-language short films": "أفلام قصيرة باللغة الإسبانية",
    "Spanish-language sports comedy films": "أفلام رياضية كوميدية باللغة الإسبانية",
    "Spanish-language sports films": "أفلام رياضية باللغة الإسبانية",
    "Spanish-language thriller films": "أفلام إثارة باللغة الإسبانية",
    "Spanish-language war films": "أفلام حربية باللغة الإسبانية",
    "Swedish-language action films": "أفلام حركة باللغة السويدية",
    "Swedish-language adventure comedy films": "أفلام مغامرات كوميدية باللغة السويدية",
    "Swedish-language adventure films": "أفلام مغامرات باللغة السويدية",
    "Swedish-language biographical films": "أفلام سير ذاتية باللغة السويدية",
    "Swedish-language comedy-drama films": "أفلام كوميدية درامية باللغة السويدية",
    "Swedish-language crime films": "أفلام جريمة باللغة السويدية",
    "Swedish-language documentary films": "أفلام وثائقية باللغة السويدية",
    "Swedish-language erotic drama films": "أفلام إغرائية درامية باللغة السويدية",
    "Swedish-language erotic films": "أفلام إغرائية باللغة السويدية",
    "Swedish-language historical drama films": "أفلام تاريخية درامية باللغة السويدية",
    "Swedish-language historical films": "أفلام تاريخية باللغة السويدية",
    "Swedish-language horror films": "أفلام رعب باللغة السويدية",
    "Swedish-language musical films": "أفلام موسيقية باللغة السويدية",
    "Swedish-language mystery films": "أفلام غموض باللغة السويدية",
    "Swedish-language mystery thriller films": "أفلام غموض إثارة باللغة السويدية",
    "Swedish-language romance films": "أفلام رومانسية باللغة السويدية",
    "Swedish-language sports films": "أفلام رياضية باللغة السويدية",
    "Swedish-language thriller films": "أفلام إثارة باللغة السويدية",
    "Tamil-language action adventure films": "أفلام حركة مغامرات باللغة التاميلية",
    "Tamil-language action comedy films": "أفلام حركة كوميدية باللغة التاميلية",
    "Tamil-language action drama films": "أفلام حركة درامية باللغة التاميلية",
    "Tamil-language action films": "أفلام حركة باللغة التاميلية",
    "Tamil-language adventure films": "أفلام مغامرات باللغة التاميلية",
    "Tamil-language biographical films": "أفلام سير ذاتية باللغة التاميلية",
    "Tamil-language comedy horror films": "أفلام كوميدية رعب باللغة التاميلية",
    "Tamil-language comedy-drama films": "أفلام كوميدية درامية باللغة التاميلية",
    "Tamil-language crime action films": "أفلام جريمة حركة باللغة التاميلية",
    "Tamil-language crime films": "أفلام جريمة باللغة التاميلية",
    "Tamil-language fantasy films": "أفلام فانتازيا باللغة التاميلية",
    "Tamil-language historical drama films": "أفلام تاريخية درامية باللغة التاميلية",
    "Tamil-language historical films": "أفلام تاريخية باللغة التاميلية",
    "Tamil-language horror films": "أفلام رعب باللغة التاميلية",
    "Tamil-language mystery thriller films": "أفلام غموض إثارة باللغة التاميلية",
    "Tamil-language romance films": "أفلام رومانسية باللغة التاميلية",
    "Tamil-language romantic thriller films": "أفلام رومانسية إثارة باللغة التاميلية",
    "Tamil-language thriller films": "أفلام إثارة باللغة التاميلية",
    "Tamil-language war films": "أفلام حربية باللغة التاميلية",
    "Telugu-language action comedy films": "أفلام حركة كوميدية باللغة التيلوغوية",
    "Telugu-language action films": "أفلام حركة باللغة التيلوغوية",
    "Telugu-language biographical films": "أفلام سير ذاتية باللغة التيلوغوية",
    "Telugu-language comedy-drama films": "أفلام كوميدية درامية باللغة التيلوغوية",
    "Telugu-language crime films": "أفلام جريمة باللغة التيلوغوية",
    "Telugu-language fantasy films": "أفلام فانتازيا باللغة التيلوغوية",
    "Telugu-language musical films": "أفلام موسيقية باللغة التيلوغوية",
    "Telugu-language romance films": "أفلام رومانسية باللغة التيلوغوية",
    "Telugu-language thriller films": "أفلام إثارة باللغة التيلوغوية",
    "Turkish-language action adventure films": "أفلام حركة مغامرات باللغة التركية",
    "Turkish-language action comedy films": "أفلام حركة كوميدية باللغة التركية",
    "Turkish-language action films": "أفلام حركة باللغة التركية",
    "Turkish-language adventure films": "أفلام مغامرات باللغة التركية",
    "Turkish-language biographical films": "أفلام سير ذاتية باللغة التركية",
    "Turkish-language comedy horror films": "أفلام كوميدية رعب باللغة التركية",
    "Turkish-language comedy-drama films": "أفلام كوميدية درامية باللغة التركية",
    "Turkish-language crime films": "أفلام جريمة باللغة التركية",
    "Turkish-language documentary films": "أفلام وثائقية باللغة التركية",
    "Turkish-language historical comedy films": "أفلام تاريخية كوميدية باللغة التركية",
    "Turkish-language historical films": "أفلام تاريخية باللغة التركية",
    "Turkish-language horror films": "أفلام رعب باللغة التركية",
    "Turkish-language romance films": "أفلام رومانسية باللغة التركية",
    "Turkish-language thriller films": "أفلام إثارة باللغة التركية",
    "Turkish-language war films": "أفلام حربية باللغة التركية",
    "Urdu-language historical films": "أفلام تاريخية باللغة الأردية",
    "Urdu-language musical films": "أفلام موسيقية باللغة الأردية",
    "Urdu-language romance films": "أفلام رومانسية باللغة الأردية",
}


to_test = [
    ("test_language_films", test_data),
]


@pytest.mark.parametrize("category, expected", test_data_0.items(), ids=test_data_0.keys())
@pytest.mark.fast
def test_language_films_0(category: str, expected: str) -> None:
    label2 = resolve_languages_labels(category)
    assert label2 == expected


@pytest.mark.parametrize("category, expected", test_data.items(), ids=test_data.keys())
@pytest.mark.fast
def test_language_films(category: str, expected: str) -> None:
    label2 = resolve_languages_labels(category)
    assert label2 == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_languages_labels)
    dump_diff(diff_result, name)

    # dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""
The categories should be like:
    - main category: softball players > لاعبو ولاعبات كرة لينة
    - male category:
        - male softball players > لاعبو كرة لينة
        - men's softball players > لاعبو كرة لينة
    - female category: women's softball players > لاعبات كرة لينة
"""

import pytest

from ArWikiCats.genders_resolvers.nat_genders_pattern_multi import (
    genders_jobs_resolver,
    genders_sports_resolver,
    resolve_nat_genders_pattern_v2,
)

sports_data = {
    "yemeni softball players": "لاعبو ولاعبات كرة لينة يمنيون",  # x
    "yemeni men's softball players": "لاعبو كرة لينة يمنيون",  # x
    "yemeni male softball players": "لاعبو كرة لينة يمنيون",  # x
    "yemeni women's softball players": "لاعبات كرة لينة يمنيات",  # ✓
    "women's softball players": "لاعبات كرة لينة",  # ✓
}


@pytest.mark.parametrize("category,expected", sports_data.items(), ids=sports_data.keys())
def test_sports_data(category: str, expected: str) -> None:
    """Test"""
    result = genders_sports_resolver(category)
    assert result == expected



"""
Tests
"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.legacy_bots.sport_lab_suffixes import resolve_team_suffix

resolve_team_suffix_data = {
    "australian rules football awards": "جوائز كرة قدم أسترالية",
    "baseball commissioners": "مفوضو كرة قاعدة",
    "baseball music": "موسيقى كرة قاعدة",
    "baseball video games": "ألعاب فيديو كرة قاعدة",
    "basketball awards": "جوائز كرة سلة",
    "basketball comics": "قصص مصورة كرة سلة",
    "basketball terminology": "مصطلحات كرة سلة",
    "bowling broadcasters": "مذيعو بولينج",
    "bowling television series": "مسلسلات تلفزيونية بولينج",
    "canoeing logos": "شعارات ركوب الكنو",
    "cycling television series": "مسلسلات تلفزيونية سباق دراجات هوائية",
    "fencing logos": "شعارات مبارزة سيف شيش",
    "figure skating media": "إعلام تزلج فني",
    "football governing bodies": "هيئات تنظيم كرة قدم",
    "go comics": "قصص مصورة غو",
    "muay thai video games": "ألعاب فيديو موياي تاي",
    "roller hockey logos": "شعارات هوكي دحرجة",
    "rowing equipment": "معدات تجديف",
    "rugby union stadiums": "ملاعب اتحاد رجبي",
    "shooting sports equipment": "معدات رماية",
    "snooker terminology": "مصطلحات سنوكر",
    "tennis logos": "شعارات كرة مضرب",
    "water polo comics": "قصص مصورة كرة ماء",
    "water polo competition": "منافسات كرة ماء",
    "wheelchair basketball terminology": "مصطلحات كرة سلة على كراسي متحركة",
}


@pytest.mark.parametrize(
    "category, expected_key", resolve_team_suffix_data.items(), ids=resolve_team_suffix_data.keys()
)
@pytest.mark.fast
def test_resolve_team_suffix_data(category: str, expected_key: str) -> None:
    label = resolve_team_suffix(category)
    assert label == expected_key


to_test = [
    ("test_resolve_team_suffix_data", resolve_team_suffix_data),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_team_suffix)
    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
Tests
"""

import pytest

from ArWikiCats import resolve_label_ar
from ArWikiCats.time_resolvers.labs_years_resolver import resolve_lab_from_years_patterns

test_data = {
    "16th century music": "الموسيقى في القرن 16",
    "16th century theatre": "المسرح في القرن 16",
    "17th century music": "الموسيقى في القرن 17",
    "17th century theatre": "المسرح في القرن 17",
    "12th-century Indian books": "كتب هندية في القرن 12",
    "1520s censuses": "تعداد السكان في عقد 1520",
    "1630s science fiction works": "أعمال خيال علمي عقد 1630",
    "1650s controversies": "خلافات عقد 1650",
    "1650s floods": "فيضانات عقد 1650",
    "1650s mass shootings": "إطلاق نار عشوائي عقد 1650",
    "1650s murders": "جرائم قتل في عقد 1650",
    "1650s science fiction works": "أعمال خيال علمي عقد 1650",
    "17th-century cookbooks": "كتب طبخ القرن 17",
    "1910s musicals": "مسرحيات غنائية عقد 1910",
    "1910s racehorse deaths": "خيول سباق نفقت في عقد 1910",
    "1914 mining disasters": "كوارث التعدين 1914",
    "1970s albums": "ألبومات عقد 1970",
    "1990s landslides": "انهيارات أرضية عقد 1990",
    "19th-century publications": "منشورات القرن 19",
    "2020s revolutions": "ثورات عقد 2020",
    "2020s transport disasters": "كوارث نقل في عقد 2020",
    "21st-century mosques": "مساجد القرن 21",
    "2nd-millennium texts": "نصوص الألفية 2",
    "15th-century executions": "إعدامات في القرن 15",
}

test_data2 = {
    "February 2020 sports-events": "أحداث فبراير 2020 الرياضية",
}


@pytest.mark.parametrize("category, expected", test_data.items(), ids=test_data.keys())
@pytest.mark.fast
def test_mk3_skips_test_data_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", test_data2.items(), ids=test_data2.keys())
@pytest.mark.fast
def test_years_data(category: str, expected: str) -> None:
    label = resolve_lab_from_years_patterns(category)
    assert label == expected



"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.countries_names_with_sports.p17_bot_sport import get_p17_with_sport_new

# =========================================================
#                   get_p17_with_sport_new
# =========================================================

data_0 = {
    "south korea national under-17 football team": "منتخب كوريا الجنوبية لكرة القدم تحت 17 سنة",
    "south korea national under-20 football team": "منتخب كوريا الجنوبية لكرة القدم تحت 20 سنة",
    "south korea national under-23 football team": "منتخب كوريا الجنوبية لكرة القدم تحت 23 سنة",
    "bosnia and herzegovina national under-21 football team": "منتخب البوسنة والهرسك لكرة القدم تحت 21 سنة",
    "sweden national under-21 football team managers": "مدربو منتخب السويد لكرة القدم تحت 21 سنة",
    "france national under-21 football team": "منتخب فرنسا لكرة القدم تحت 21 سنة",
    "germany national under-21 football team managers": "مدربو منتخب ألمانيا لكرة القدم تحت 21 سنة",
    "colombia national under-20 football team managers": "مدربو منتخب كولومبيا لكرة القدم تحت 20 سنة",
    "brazil national under-23 football team results": "نتائج منتخب البرازيل لكرة القدم تحت 23 سنة",
    "australia national men's under-23 soccer team": "منتخب أستراليا لكرة القدم تحت 23 سنة للرجال",
}


@pytest.mark.parametrize("category, expected", data_0.items(), ids=data_0.keys())
@pytest.mark.fast
def test_get_p17_with_sport_1(category: str, expected: str) -> None:
    label1 = get_p17_with_sport_new(category)
    assert label1 == expected


# =========================================================
#                   DUMP
# =========================================================


TEMPORAL_CASES = [
    ("test_get_p17_with_sport_1", data_0, get_p17_with_sport_new),
]


@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback, do_strip=False)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



# test_convert_time_to_arabic.py
# -*- coding: utf-8 -*-
import pytest

from ArWikiCats.time_resolvers.time_to_arabic import (
    convert_time_to_arabic,
    match_time_ar,
    match_time_en,
    match_time_en_first,
)


@pytest.mark.parametrize(
    "en_text, expected",
    [
        # --- Months ---
        ("March 1917", "مارس 1917"),
        ("August 2025", "أغسطس 2025"),
        ("December 1999", "ديسمبر 1999"),
        # --- Decades ---
        ("2020s", "عقد 2020"),
        ("1990s", "عقد 1990"),
        ("10s", "عقد 10"),
        ("10s BC", "عقد 10 ق م"),
        # --- Centuries ---
        ("19th century", "القرن 19"),
        ("2nd century BC", "القرن 2 ق م"),
        ("4th-century BCE", "القرن 4 ق م"),
        ("4th-century BC", "القرن 4 ق م"),
        ("21st century BCE", "القرن 21 ق م"),
        ("1st century", "القرن 1"),
        # --- Millennia ---
        ("2nd millennium", "الألفية 2"),
        ("1st millennium BC", "الألفية 1 ق م"),
        ("2nd millennium BC", "الألفية 2 ق م"),
        ("1st millennium BCE", "الألفية 1 ق م"),
        # --- Misc / fallback ---
        ("1000", "1000"),
        ("1234", "1234"),
        ("Late 20th century", ""),  # no pattern
        ("year 2000", ""),  # should not alter arbitrary text
    ],
)
def test_convert_time_to_arabic_basic(en_text: str, expected: str) -> None:
    """Test various English time expressions for correct Arabic conversion."""
    result = convert_time_to_arabic(en_text)
    assert result == expected, f"{en_text} → {result}, {expected=}"


@pytest.mark.parametrize(
    "en_text, expected",
    [
        # --- Numeric ranges ---
        ("2012–13", "2012–13"),
        ("2012-2013", "2012-2013"),
        ("1990–91", "1990–91"),
        ("1990-1991", "1990-1991"),
        ("1800-1899", "1800-1899"),
        ("1999-2001", "1999-2001"),
        ("1999–01", "1999–01"),
        ("1899–01", "1899–01"),
    ],
)
@pytest.mark.fast
def test_ranges(en_text: str, expected: str) -> None:
    """Test various English time expressions for correct Arabic conversion."""
    result = convert_time_to_arabic(en_text)
    assert result == expected, f"{en_text} → {result}, {expected=}"


@pytest.mark.fast
def test_trim_and_dash_normalization() -> None:
    """Ensure spaces and en dash normalization work."""
    result = convert_time_to_arabic("  March 1917 ")
    assert result == "مارس 1917"

    result = convert_time_to_arabic("2012–13")
    assert result == "2012–13"


@pytest.mark.fast
def test_nonstandard_inputs() -> None:
    """Edge cases and nonstandard input should not crash."""
    assert convert_time_to_arabic("") == ""
    assert convert_time_to_arabic("unknown") == ""
    assert convert_time_to_arabic("123abc") == ""
    assert convert_time_to_arabic("20th-century architecture") == ""


@pytest.mark.fast
def test_century_and_millennium_bc_equivalence() -> None:
    """Verify BC and BCE handled identically."""
    assert convert_time_to_arabic("2nd century BC") == convert_time_to_arabic("2nd century BCE")
    assert convert_time_to_arabic("1st millennium BC") == convert_time_to_arabic("1st millennium BCE")


@pytest.mark.fast
def test_convert_time_to_arabic_decade_bc() -> None:
    # 10s BC should be mapped to عقد 10 ق م
    assert convert_time_to_arabic("10s BC") == "عقد 10 ق م"


@pytest.mark.fast
def test_convert_time_to_arabic_decade_normal() -> None:
    # 1990s should be mapped to عقد 1990
    assert convert_time_to_arabic("1990s") == "عقد 1990"


@pytest.mark.parametrize(
    "en_text, expected",
    [
        ("march   1917", "مارس 1917"),
        (" MARCH 1917", "مارس 1917"),
        ("April    2020", "أبريل 2020"),
        ("July  0099", "يوليو 0099"),
    ],
)
@pytest.mark.fast
def test_month_variants(en_text: str, expected: str) -> None:
    assert convert_time_to_arabic(en_text) == expected


@pytest.mark.parametrize(
    "en_text, expected",
    [
        ("0010s", "عقد 0010"),
        ("0010s BC", "عقد 0010 ق م"),
        ("50s", "عقد 50"),
        ("50s BC", "عقد 50 ق م"),
        ("5s", "عقد 5"),
        ("5s BC", "عقد 5 ق م"),
        ("1990S", "عقد 1990"),  # case insensitive
        ("1990S BC", "عقد 1990 ق م"),
    ],
)
@pytest.mark.fast
def test_decade_all_variants(en_text: str, expected: str) -> None:
    assert convert_time_to_arabic(en_text) == expected


@pytest.mark.parametrize(
    "en_text, expected",
    [
        ("20th-century", "القرن 20"),
        ("20th-century BC", "القرن 20 ق م"),
        ("7th centuryBC", "القرن 7 ق م"),
        ("1st-century", "القرن 1"),
        ("1st-century BCE", "القرن 1 ق م"),
        ("25th century", "القرن 25"),  # للتأكد من أرقام كبيرة
    ],
)
@pytest.mark.fast
def test_century_extended(en_text: str, expected: str) -> None:
    assert convert_time_to_arabic(en_text) == expected


@pytest.mark.parametrize(
    "en_text, expected",
    [
        ("1st-millennium", "الألفية 1"),
        ("1st-millennium BC", "الألفية 1 ق م"),
        ("10th millennium", "الألفية 10"),
    ],
)
@pytest.mark.fast
def test_millennium_extended(en_text: str, expected: str) -> None:
    assert convert_time_to_arabic(en_text) == expected


@pytest.mark.parametrize(
    "en_text",
    [
        "1990-91",
        "1990–91",
        "1990−91",
        "1990-91",
        "1990-91",  # non-breaking hyphen
    ],
)
@pytest.mark.fast
def test_ranges_all_dash_forms(en_text) -> None:
    assert convert_time_to_arabic(en_text) == en_text


@pytest.mark.parametrize(
    "text, expected",
    [
        ("Events in 1990s BC", ["1990s BC"]),
        ("From March 1917 to August 2020", ["March 1917", "August 2020"]),
        ("Bridges built in the 4th century BC", ["4th century BC"]),
        ("In the 1st millennium BCE", ["1st millennium BCE"]),
        ("Category:2nd millennium BCE", ["2nd millennium BCE"]),
        ("Category:1st millennium BC", ["1st millennium BC"]),
        ("Category:5th century BCE", ["5th century BCE"]),
        ("10th century bc", ["10th century bc"]),
        # Four-digit year inside parentheses
        ("Category:American Soccer League (1933)", ["1933"]),
        ("Category:American Soccer League (1933–83)", ["1933–83"]),
    ],
)
@pytest.mark.fast
def test_match_time_en(text: str, expected: list[str]) -> None:
    assert match_time_en(text) == expected
    assert match_time_en_first(text) == expected[0]


@pytest.mark.parametrize(
    "text, expected",
    [
        ("مارس 1917", ["مارس 1917"]),
        ("عقد 1990", ["عقد 1990"]),
        ("القرن 5", ["القرن 5"]),
        ("الألفية 2 ق م", ["الألفية 2 ق م"]),
    ],
)
@pytest.mark.fast
def test_match_time_ar(text: str, expected: list[str]) -> None:
    assert match_time_ar(text) == expected


@pytest.mark.parametrize(
    "text",
    [
        "not a date",
        "century-old building",
        "pre-20th century event",
        "late 1990s music",
        "about 2000 people",
        "1948–49 in european football",
    ],
)
@pytest.mark.fast
def test_fallback(text) -> None:
    assert convert_time_to_arabic(text) == ""
